class _EventInfo:
 """ Exposes the public members of the System.Reflection.EventInfo class to unmanaged code. """
 def AddEventHandler(self,target,handler):
  """
  AddEventHandler(self: _EventInfo,target: object,handler: Delegate)

   Provides COM objects with version-independent access to the 

    System.Reflection.EventInfo.AddEventHandler(System.Object,System.Delegate) method.

  

  

   target: The event source.

   handler: A method or methods to be invoked when the event is raised by the target.
  """
  pass
 def Equals(self,other):
  """
  Equals(self: _EventInfo,other: object) -> bool

  

   Provides COM objects with version-independent access to the System.Object.Equals(System.Object) 

    method.

  

  

   other: The System.Object to compare with the current System.Object.

   Returns: true if the specified System.Object is equal to the current System.Object; otherwise,false.
  """
  pass
 def GetAddMethod(self,nonPublic=None):
  """
  GetAddMethod(self: _EventInfo) -> MethodInfo

  

   Provides COM objects with version-independent access to the 

    System.Reflection.EventInfo.GetAddMethod method.

  

   Returns: A System.Reflection.MethodInfo object representing the method used to add an event-handler 

    delegate to the event source.

  

  GetAddMethod(self: _EventInfo,nonPublic: bool) -> MethodInfo

  

   Provides COM objects with version-independent access to the 

    System.Reflection.EventInfo.GetAddMethod(System.Boolean) method.

  

  

   nonPublic: true to return non-public methods; otherwise,false.

   Returns: A System.Reflection.MethodInfo object representing the method used to add an event-handler 

    delegate to the event source.
  """
  pass
 def GetCustomAttributes(self,*__args):
  """
  GetCustomAttributes(self: _EventInfo,inherit: bool) -> Array[object]

  

   Provides COM objects with version-independent access to the 

    System.Reflection.MemberInfo.GetCustomAttributes(System.Boolean) method.

  

  

   inherit: true to search a member's inheritance chain to find the attributes; otherwise,false.

   Returns: An array that contains all the custom attributes,or an array with zero (0) elements if no 

    attributes are defined.

  

  GetCustomAttributes(self: _EventInfo,attributeType: Type,inherit: bool) -> Array[object]

  

   Provides COM objects with version-independent access to the 

    System.Reflection.MemberInfo.GetCustomAttributes(System.Type,System.Boolean) method.

  

  

   attributeType: The type of attribute to search for. Only attributes that are assignable to this type are 

    returned.

  

   inherit: true to search this member's inheritance chain to find the attributes; otherwise,false.

   Returns: An array of custom attributes applied to this member,or an array with zero (0) elements if no 

    attributes have been applied.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: _EventInfo) -> int

  

   Provides COM objects with version-independent access to the System.Object.GetHashCode method.

   Returns: The hash code for the current instance.
  """
  pass
 def GetIDsOfNames(self,riid,rgszNames,cNames,lcid,rgDispId):
  """
  GetIDsOfNames(self: _EventInfo,riid: Guid,rgszNames: IntPtr,cNames: UInt32,lcid: UInt32,rgDispId: IntPtr) -> Guid

  

   Maps a set of names to a corresponding set of dispatch identifiers.

  

   riid: Reserved for future use. Must be IID_NULL.

   rgszNames: An array of names to be mapped.

   cNames: The count of the names to be mapped.

   lcid: The locale context in which to interpret the names.

   rgDispId: An array allocated by the caller that receives the identifiers corresponding to the names.
  """
  pass
 def GetRaiseMethod(self,nonPublic=None):
  """
  GetRaiseMethod(self: _EventInfo) -> MethodInfo

  

   Provides COM objects with version-independent access to the 

    System.Reflection.EventInfo.GetRaiseMethod method.

  

   Returns: The method that is called when the event is raised.

  GetRaiseMethod(self: _EventInfo,nonPublic: bool) -> MethodInfo

  

   Provides COM objects with version-independent access to the 

    System.Reflection.EventInfo.GetRaiseMethod(System.Boolean) method.

  

  

   nonPublic: true to return non-public methods; otherwise,false.

   Returns: The System.Reflection.MethodInfo object that was called when the event was raised.
  """
  pass
 def GetRemoveMethod(self,nonPublic=None):
  """
  GetRemoveMethod(self: _EventInfo) -> MethodInfo

  

   Provides COM objects with version-independent access to the 

    System.Reflection.EventInfo.GetRemoveMethod method.

  

   Returns: A System.Reflection.MethodInfo object representing the method used to remove an event-handler 

    delegate from the event source.

  

  GetRemoveMethod(self: _EventInfo,nonPublic: bool) -> MethodInfo

  

   Provides COM objects with version-independent access to the 

    System.Reflection.EventInfo.GetRemoveMethod(System.Boolean) method.

  

  

   nonPublic: true to return non-public methods; otherwise,false.

   Returns: A System.Reflection.MethodInfo object representing the method used to remove an event-handler 

    delegate from the event source.
  """
  pass
 def GetType(self):
  """
  GetType(self: _EventInfo) -> Type

  

   Provides COM objects with version-independent access to the System.Object.GetType method.

   Returns: A System.Type object.
  """
  pass
 def GetTypeInfo(self,iTInfo,lcid,ppTInfo):
  """
  GetTypeInfo(self: _EventInfo,iTInfo: UInt32,lcid: UInt32,ppTInfo: IntPtr)

   Retrieves the type information for an object,which can be used to get the type information for 

    an interface.

  

  

   iTInfo: The type information to return.

   lcid: The locale identifier for the type information.

   ppTInfo: A pointer to the requested type information object.
  """
  pass
 def GetTypeInfoCount(self,pcTInfo):
  """
  GetTypeInfoCount(self: _EventInfo) -> UInt32

  

   Retrieves the number of type information interfaces that an object provides (either 0 or 1).
  """
  pass
 def Invoke(self,dispIdMember,riid,lcid,wFlags,pDispParams,pVarResult,pExcepInfo,puArgErr):
  """
  Invoke(self: _EventInfo,dispIdMember: UInt32,riid: Guid,lcid: UInt32,wFlags: Int16,pDispParams: IntPtr,pVarResult: IntPtr,pExcepInfo: IntPtr,puArgErr: IntPtr) -> Guid

  

   Provides access to properties and methods exposed by an object.

  

   dispIdMember: An identifier for the member.

   riid: Reserved for future use. Must be IID_NULL.

   lcid: The locale context in which to interpret arguments.

   wFlags: Flags describing the context of the call.

   pDispParams: A pointer to a structure containing an array of arguments,an array of argument DISPIDs for 

    named arguments,and counts for the number of elements in the arrays.

  

   pVarResult: A pointer to the location where the result will be stored.

   pExcepInfo: A pointer to a structure that contains exception information.

   puArgErr: The index of the first argument that has an error.
  """
  pass
 def IsDefined(self,attributeType,inherit):
  """
  IsDefined(self: _EventInfo,attributeType: Type,inherit: bool) -> bool

  

   Provides COM objects with version-independent access to the 

    System.Reflection.MemberInfo.IsDefined(System.Type,System.Boolean) method.

  

  

   attributeType: The Type object to which the custom attributes are applied.

   inherit: true to search this member's inheritance chain to find the attributes; otherwise,false.

   Returns: true if one or more instance of the attributeType parameter is applied to this member; 

    otherwise,false.
  """
  pass
 def RemoveEventHandler(self,target,handler):
  """
  RemoveEventHandler(self: _EventInfo,target: object,handler: Delegate)

   Provides COM objects with version-independent access to the 

    System.Reflection.EventInfo.RemoveEventHandler(System.Object,System.Delegate) method.

  

  

   target: The event source.

   handler: The delegate to be disassociated from the events raised by target.
  """
  pass
 def ToString(self):
  """
  ToString(self: _EventInfo) -> str

  

   Provides COM objects with version-independent access to the System.Object.ToString method.

   Returns: A string that represents the current System.Object.
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __str__(self,*args):
  pass
 Attributes=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Reflection.EventInfo.Attributes property.



Get: Attributes(self: _EventInfo) -> EventAttributes



"""

 DeclaringType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Reflection.MemberInfo.DeclaringType property.



Get: DeclaringType(self: _EventInfo) -> Type



"""

 EventHandlerType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Reflection.EventInfo.EventHandlerType property.



Get: EventHandlerType(self: _EventInfo) -> Type



"""

 IsMulticast=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Reflection.EventInfo.IsMulticast property.



Get: IsMulticast(self: _EventInfo) -> bool



"""

 IsSpecialName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Reflection.EventInfo.IsSpecialName property.



Get: IsSpecialName(self: _EventInfo) -> bool



"""

 MemberType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Reflection.EventInfo.MemberType property.



Get: MemberType(self: _EventInfo) -> MemberTypes



"""

 Name=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Reflection.MemberInfo.Name property.



Get: Name(self: _EventInfo) -> str



"""

 ReflectedType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Provides COM objects with version-independent access to the System.Reflection.MemberInfo.ReflectedType property.



Get: ReflectedType(self: _EventInfo) -> Type



"""





"""Assembly maker module."""
import os.path as op
from collections import namedtuple

from pyrevit import PYREVIT_ADDON_NAME, EXEC_PARAMS
from pyrevit.compat import NETCORE
from pyrevit import framework
from pyrevit.framework import AppDomain, Version
from pyrevit.framework import AssemblyName, AssemblyBuilderAccess
from pyrevit import coreutils
from pyrevit.coreutils import assmutils
from pyrevit.coreutils import appdata
from pyrevit.coreutils import logger
from pyrevit.versionmgr import get_pyrevit_version

from pyrevit.loader import HASH_CUTOFF_LENGTH
from pyrevit.runtime import BASE_TYPES_DIR_HASH
from pyrevit.runtime import typemaker
from pyrevit.userconfig import user_config

from System.Reflection.Emit import AssemblyBuilder

# Generic named tuple for passing assembly information to other modules
ExtensionAssemblyInfo = namedtuple('ExtensionAssemblyInfo',
                                   ['name', 'location', 'reloading'])


#pylint: disable=W0703,C0302,C0103
mlogger = logger.get_logger(__name__)


def _make_extension_hash(extension):
    # creates a hash based on hash of baseclasses module that
    # the extension is based upon and also the user configuration version
    return coreutils.get_str_hash(
        BASE_TYPES_DIR_HASH
        + EXEC_PARAMS.engine_ver
        + extension.get_hash())[:HASH_CUTOFF_LENGTH]


def _make_ext_asm_fileid(extension):
    return '{}_{}'.format(_make_extension_hash(extension), extension.name)


def _is_pyrevit_ext_asm(asm_name, extension):
    # if this is a pyRevit package assembly
    return asm_name.startswith(PYREVIT_ADDON_NAME) \
           and asm_name.endswith(extension.name)


def _is_pyrevit_ext_already_loaded(ext_asm_name):
    mlogger.debug('Asking Revit for previously loaded package assemblies: %s',
                  ext_asm_name)
    return len(assmutils.find_loaded_asm(ext_asm_name))


def _is_any_ext_asm_loaded(extension):
    for loaded_asm in AppDomain.CurrentDomain.GetAssemblies():
        mlogger.debug('Checking for loaded extension asm: %s ? %s : %s',
                      extension.name, loaded_asm.GetName().Name, loaded_asm)
        if _is_pyrevit_ext_asm(loaded_asm.GetName().Name, extension):
            return True
    return False


def _update_component_cmd_types(extension):
    for cmd_component in extension.get_all_commands():
        typemaker.make_bundle_types(
            extension,
            cmd_component,
            module_builder=None
            )


def _create_asm_file(extension, ext_asm_file_name, ext_asm_file_path):
    # check to see if any older assemblies have been loaded for this package
    ext_asm_full_file_name = \
        coreutils.make_canonical_name(ext_asm_file_name,
                                      framework.ASSEMBLY_FILE_TYPE)

    # this means that we currently have this package loaded and
    # we're reloading a new version
    is_reloading_pkg = _is_any_ext_asm_loaded(extension)

    # create assembly
    mlogger.debug('Building assembly for package: %s', extension)
    pyrvt_ver_int_tuple = get_pyrevit_version().as_int_tuple()
    win_asm_name = AssemblyName(Name=ext_asm_file_name,
                                Version=Version(pyrvt_ver_int_tuple[0],
                                                pyrvt_ver_int_tuple[1],
                                                pyrvt_ver_int_tuple[2]))
    mlogger.debug('Generated assembly name for this package: %s',
                  ext_asm_file_name)
    mlogger.debug('Generated windows assembly name for this package: %s',
                  win_asm_name)
    mlogger.debug('Generated assembly file name for this package: %s',
                  ext_asm_full_file_name)

    if NETCORE:
        asm_builder = AssemblyBuilder.DefineDynamicAssembly(
            win_asm_name,
            AssemblyBuilderAccess.Run)

        # get module builder
        module_builder = asm_builder.DefineDynamicModule(ext_asm_file_name)
    else:
        # get assembly builder
        asm_builder = AppDomain.CurrentDomain.DefineDynamicAssembly(
            win_asm_name,
            AssemblyBuilderAccess.RunAndSave,
            op.dirname(ext_asm_file_path))

        # get module builder
        module_builder = asm_builder.DefineDynamicModule(ext_asm_file_name,
                                                         ext_asm_full_file_name)

    # create command classes
    for cmd_component in extension.get_all_commands():
        # create command executor class for this command
        mlogger.debug('Creating types for command: %s', cmd_component)
        typemaker.make_bundle_types(extension, cmd_component, module_builder)

    if NETCORE:
        from Lokad.ILPack import AssemblyGenerator
        generator = AssemblyGenerator()
        generator.GenerateAssembly(asm_builder, ext_asm_file_path)
    else:
        # save final assembly
        asm_builder.Save(ext_asm_full_file_name)

    assmutils.load_asm_file(ext_asm_file_path)

    mlogger.debug('Executer assembly saved.')
    return ExtensionAssemblyInfo(ext_asm_file_name,
                                 ext_asm_file_path,
                                 is_reloading_pkg)


def _produce_asm_file(extension):
    # unique assembly filename for this package
    ext_asm_fileid = _make_ext_asm_fileid(extension)
    ext_asm_file_path = \
        appdata.get_data_file(file_id=ext_asm_fileid,
                              file_ext=framework.ASSEMBLY_FILE_TYPE)
    # make unique assembly name for this package
    ext_asm_file_name = coreutils.get_file_name(ext_asm_file_path)

    if _is_pyrevit_ext_already_loaded(ext_asm_file_name):
        mlogger.debug('Extension assembly is already loaded: %s',
                      ext_asm_file_name)
        _update_component_cmd_types(extension)
        return ExtensionAssemblyInfo(ext_asm_file_name, ext_asm_file_path, True)
    elif appdata.is_data_file_available(
            file_id=ext_asm_fileid,
            file_ext=framework.ASSEMBLY_FILE_TYPE):
        mlogger.debug('Extension assembly file already exists: %s',
                      ext_asm_file_path)
        try:
            loaded_assm = assmutils.load_asm_file(ext_asm_file_path)
            for asm_name in loaded_assm.GetReferencedAssemblies():
                mlogger.debug('Checking referenced assembly: %s', asm_name)
                ref_asm_file_path = \
                    appdata.is_file_available(
                        file_name=asm_name.Name,
                        file_ext=framework.ASSEMBLY_FILE_TYPE
                        )
                if ref_asm_file_path:
                    mlogger.debug('Loading referenced assembly: %s',
                                  ref_asm_file_path)
                    try:
                        assmutils.load_asm_file(ref_asm_file_path)
                    except Exception as load_err:
                        mlogger.error('Error loading referenced assembly: %s '
                                      '| %s', ref_asm_file_path, load_err)

            _update_component_cmd_types(extension)
            return ExtensionAssemblyInfo(ext_asm_file_name,
                                         ext_asm_file_path,
                                         False)
        except Exception as ext_asm_load_err:
            mlogger.error('Error loading extension assembly: %s | %s',
                          ext_asm_file_path, ext_asm_load_err)
    else:
        return _create_asm_file(extension,
                                ext_asm_file_name,
                                ext_asm_file_path)


def create_assembly(extension):
    """Create an extension assembly.

    Args:
        extension (pyrevit.extensions.components.Extension): pyRevit extension.

    Returns:
        (ExtensionAssemblyInfo): assembly info
    """
    mlogger.debug('Creating assembly for extension: %s', extension.name)
    # create assembly file and return assembly path to be used in UI creation
    # try:
    ext_asm_info = _produce_asm_file(extension)
    mlogger.debug('Assembly created: %s', ext_asm_info)
    return ext_asm_info
    # except Exception as asm_err:
    #     mlogger.critical('Can not create assembly for: {}' \
    #                     '| {}'.format(extension, asm_err))


def cleanup_assembly_files():
    if coreutils.get_revit_instance_count() == 1:
        for asm_file_path in appdata.list_data_files(file_ext='dll'):
            if not assmutils.find_loaded_asm(asm_file_path, by_location=True):
                appdata.garbage_data_file(asm_file_path)
                asm_log_file = asm_file_path.replace('.dll', '.log')
                if op.exists(asm_log_file):
                    appdata.garbage_data_file(asm_log_file)



class CurrencyManager(BindingManagerBase):
 """ Manages a list of System.Windows.Forms.Binding objects. """
 def AddNew(self):
  """
  AddNew(self: CurrencyManager)

   Adds a new item to the underlying list.
  """
  pass
 def CancelCurrentEdit(self):
  """
  CancelCurrentEdit(self: CurrencyManager)

   Cancels the current edit operation.
  """
  pass
 def CheckEmpty(self,*args):
  """
  CheckEmpty(self: CurrencyManager)

   Throws an exception if there is no list,or the list is empty.
  """
  pass
 def EndCurrentEdit(self):
  """
  EndCurrentEdit(self: CurrencyManager)

   Ends the current edit operation.
  """
  pass
 def GetItemProperties(self):
  """
  GetItemProperties(self: CurrencyManager) -> PropertyDescriptorCollection

  

   Gets the property descriptor collection for the underlying list.

   Returns: A System.ComponentModel.PropertyDescriptorCollection for the list.
  """
  pass
 def OnItemChanged(self,*args):
  """
  OnItemChanged(self: CurrencyManager,e: ItemChangedEventArgs)

   Raises the System.Windows.Forms.CurrencyManager.ItemChanged event.

  

   e: An System.Windows.Forms.ItemChangedEventArgs that contains the event data.
  """
  pass
 def OnMetaDataChanged(self,*args):
  """
  OnMetaDataChanged(self: CurrencyManager,e: EventArgs)

   Raises the System.Windows.Forms.CurrencyManager.MetaDataChanged event.

  

   e: An System.EventArgs that contains the event data.
  """
  pass
 def OnPositionChanged(self,*args):
  """
  OnPositionChanged(self: CurrencyManager,e: EventArgs)

   Raises the System.Windows.Forms.BindingManagerBase.PositionChanged event.

  

   e: An System.EventArgs that contains the event data.
  """
  pass
 def Refresh(self):
  """
  Refresh(self: CurrencyManager)

   Forces a repopulation of the data-bound list.
  """
  pass
 def RemoveAt(self,index):
  """
  RemoveAt(self: CurrencyManager,index: int)

   Removes the item at the specified index.

  

   index: The index of the item to remove from the list.
  """
  pass
 def ResumeBinding(self):
  """
  ResumeBinding(self: CurrencyManager)

   Resumes data binding.
  """
  pass
 def SuspendBinding(self):
  """
  SuspendBinding(self: CurrencyManager)

   Suspends data binding to prevents changes from updating the bound data source.
  """
  pass
 Count=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the number of items in the list.



Get: Count(self: CurrencyManager) -> int



"""

 Current=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the current item in the list.



Get: Current(self: CurrencyManager) -> object



"""

 List=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the list for this System.Windows.Forms.CurrencyManager.



Get: List(self: CurrencyManager) -> IList



"""

 Position=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the position you are at within the list.



Get: Position(self: CurrencyManager) -> int



Set: Position(self: CurrencyManager)=value

"""


 finalType=None
 ItemChanged=None
 ListChanged=None
 listposition=None
 MetaDataChanged=None
 onCurrentChangedHandler=None
 onPositionChangedHandler=None




"""Read and Write PTS PointCloud Files."""


def load(inputfile):
    """Read list of point tuple from PTS file."""
    points = []
    with open(inputfile, 'r') as ptsfile:
        # point_count = int(ptsfile.readline())   #noqa
        for line in ptsfile:
            data = line.split(' ')
            points.append(((float(data[0]), float(data[1]), float(data[2])),
                           int(data[3]),
                           (int(data[4]), int(data[5]), int(data[6])))
                          )
    return points


def dump(outputfile, points):
    """Write list of point tuple to PTS file."""
    point_count = len(points)
    with open(outputfile, 'w') as ptsfile:
        ptsfile.write(str(point_count) + '\n')
        for coord, intensity, color in points:
            x, y, z = coord
            r, g, b = color
            ptsfile.write('{:.10f} {:.10f} {:.10f} '
                          '{} '
                          '{:03} {:03} {:03}\n'.format(x, y, z,
                                                       intensity,
                                                       r, g, b))



class SizeKeyFrameCollection(Freezable,ISealable,IList,ICollection,IEnumerable):
 """
 Represents a collection of System.Windows.Media.Animation.SizeKeyFrame objects.

 

 SizeKeyFrameCollection()
 """
 def Add(self,keyFrame):
  """
  Add(self: SizeKeyFrameCollection,keyFrame: SizeKeyFrame) -> int

  

   Adds a System.Windows.Media.Animation.SizeKeyFrame to the end of the collection.

  

   keyFrame: The System.Windows.Media.Animation.SizeKeyFrame to add to the end of the collection.

   Returns: The index at which the keyFrame was added.
  """
  pass
 def Clear(self):
  """
  Clear(self: SizeKeyFrameCollection)

   Removes all System.Windows.Media.Animation.SizeKeyFrame objects from the collection.
  """
  pass
 def Clone(self):
  """
  Clone(self: SizeKeyFrameCollection) -> SizeKeyFrameCollection

  

   Creates a modifiable clone of this System.Windows.Media.Animation.SizeKeyFrameCollection,making 

    deep copies of this object's values. When copying dependency properties,this method copies 

    resource references and data bindings (but they might no longer resolve) but not animations or 

    their current values.

  

   Returns: A modifiable clone of the current object. The cloned object's System.Windows.Freezable.IsFrozen 

    property will be false even if the source's System.Windows.Freezable.IsFrozen property was true.
  """
  pass
 def CloneCore(self,*args):
  """
  CloneCore(self: SizeKeyFrameCollection,sourceFreezable: Freezable)

   Makes this instance a deep copy of the specified 

    System.Windows.Media.Animation.SizeKeyFrameCollection. When copying dependency properties,this 

    method copies resource references and data bindings (but they might no longer resolve) but not 

    animations or their current values.

  

  

   sourceFreezable: The System.Windows.Media.Animation.SizeKeyFrameCollection to clone.
  """
  pass
 def CloneCurrentValueCore(self,*args):
  """
  CloneCurrentValueCore(self: SizeKeyFrameCollection,sourceFreezable: Freezable)

   Makes this instance a modifiable deep copy of the specified 

    System.Windows.Media.Animation.SizeKeyFrameCollection using current property values. Resource 

    references,data bindings,and animations are not copied,but their current values are.

  

  

   sourceFreezable: The System.Windows.Media.Animation.SizeKeyFrameCollection to clone.
  """
  pass
 def Contains(self,keyFrame):
  """
  Contains(self: SizeKeyFrameCollection,keyFrame: SizeKeyFrame) -> bool

  

   Gets a value that indicates whether the collection contains the specified 

    System.Windows.Media.Animation.SizeKeyFrame.

  

  

   keyFrame: The System.Windows.Media.Animation.SizeKeyFrame to locate in the collection.

   Returns: true if the collection contains keyFrame; otherwise,false.
  """
  pass
 def CopyTo(self,array,index):
  """
  CopyTo(self: SizeKeyFrameCollection,array: Array[SizeKeyFrame],index: int)

   Copies all of the System.Windows.Media.Animation.SizeKeyFrame objects in a collection to a 

    specified array.

  

  

   array: Identifies the array to which content is copied.

   index: Index position in the array to which the contents of the collection are copied.
  """
  pass
 def CreateInstance(self,*args):
  """
  CreateInstance(self: Freezable) -> Freezable

  

   Initializes a new instance of the System.Windows.Freezable class.

   Returns: The new instance.
  """
  pass
 def CreateInstanceCore(self,*args):
  """
  CreateInstanceCore(self: SizeKeyFrameCollection) -> Freezable

  

   Creates a new,frozen instance of System.Windows.Media.Animation.SizeKeyFrameCollection.

   Returns: A frozen instance of System.Windows.Media.Animation.SizeKeyFrameCollection.
  """
  pass
 def FreezeCore(self,*args):
  """
  FreezeCore(self: SizeKeyFrameCollection,isChecking: bool) -> bool

  

   Makes this instance of System.Windows.Media.Animation.SizeKeyFrameCollection unmodifiable or 

    determines whether it can be made unmodifiable.

  

  

   isChecking: true to check if this instance can be frozen; false to freeze this instance.

   Returns: If isChecking is true,this method returns true if this instance can be made read-only,or false 

    if it cannot be made read-only. If isChecking is false,this method returns true if this 

    instance is now read-only,or false if it cannot be made read-only,with the side effect of 

    having begun to change the frozen status of this object.
  """
  pass
 def GetAsFrozenCore(self,*args):
  """
  GetAsFrozenCore(self: SizeKeyFrameCollection,sourceFreezable: Freezable)

   Makes this instance a clone of the specified 

    System.Windows.Media.Animation.SizeKeyFrameCollection object.

  

  

   sourceFreezable: The System.Windows.Media.Animation.SizeKeyFrameCollection object to clone.
  """
  pass
 def GetCurrentValueAsFrozenCore(self,*args):
  """
  GetCurrentValueAsFrozenCore(self: SizeKeyFrameCollection,sourceFreezable: Freezable)

   Makes this instance a frozen clone of the specified 

    System.Windows.Media.Animation.SizeKeyFrameCollection. Resource references,data bindings,and 

    animations are not copied,but their current values are.

  

  

   sourceFreezable: The System.Windows.Media.Animation.SizeKeyFrameCollection to copy and freeze.
  """
  pass
 def GetEnumerator(self):
  """
  GetEnumerator(self: SizeKeyFrameCollection) -> IEnumerator

  

   Returns an enumerator that can iterate through the collection.

   Returns: An System.Collections.IEnumerator that can iterate through the collection.
  """
  pass
 def IndexOf(self,keyFrame):
  """
  IndexOf(self: SizeKeyFrameCollection,keyFrame: SizeKeyFrame) -> int

  

   Searches for the specified System.Windows.Media.Animation.SizeKeyFrame and returns the 

    zero-based index of the first occurrence within the entire collection.

  

  

   keyFrame: The System.Windows.Media.Animation.SizeKeyFrame to locate in the collection.

   Returns: The zero-based index of the first occurrence of keyFrame within the entire collection,if found; 

    otherwise,-1.
  """
  pass
 def Insert(self,index,keyFrame):
  """
  Insert(self: SizeKeyFrameCollection,index: int,keyFrame: SizeKeyFrame)

   Inserts a System.Windows.Media.Animation.SizeKeyFrame into a specific location within the 

    collection.

  

  

   index: The index position at which the System.Windows.Media.Animation.SizeKeyFrame is inserted.

   keyFrame: The System.Windows.Media.Animation.SizeKeyFrame object to insert in the collection.
  """
  pass
 def OnChanged(self,*args):
  """
  OnChanged(self: Freezable)

   Called when the current System.Windows.Freezable object is modified.
  """
  pass
 def OnFreezablePropertyChanged(self,*args):
  """
  OnFreezablePropertyChanged(self: Freezable,oldValue: DependencyObject,newValue: DependencyObject,property: DependencyProperty)

   This member supports the Windows Presentation Foundation (WPF) infrastructure and is not 

    intended to be used directly from your code.

  

  

   oldValue: The previous value of the data member.

   newValue: The current value of the data member.

   property: The property that changed.

  OnFreezablePropertyChanged(self: Freezable,oldValue: DependencyObject,newValue: DependencyObject)

   Ensures that appropriate context pointers are established for a 

    System.Windows.DependencyObjectType data member that has just been set.

  

  

   oldValue: The previous value of the data member.

   newValue: The current value of the data member.
  """
  pass
 def OnPropertyChanged(self,*args):
  """
  OnPropertyChanged(self: Freezable,e: DependencyPropertyChangedEventArgs)

   Overrides the System.Windows.DependencyObject implementation of 

    System.Windows.DependencyObject.OnPropertyChanged(System.Windows.DependencyPropertyChangedEventAr

    gs) to also invoke any System.Windows.Freezable.Changed handlers in response to a changing 

    dependency property of type System.Windows.Freezable.

  

  

   e: Event data that contains information about which property changed,and its old and new values.
  """
  pass
 def ReadPreamble(self,*args):
  """
  ReadPreamble(self: Freezable)

   Ensures that the System.Windows.Freezable is being accessed from a valid thread. Inheritors of 

    System.Windows.Freezable must call this method at the beginning of any API that reads data 

    members that are not dependency properties.
  """
  pass
 def Remove(self,keyFrame):
  """
  Remove(self: SizeKeyFrameCollection,keyFrame: SizeKeyFrame)

   Removes a System.Windows.Media.Animation.SizeKeyFrame object from the collection.

  

   keyFrame: Identifies the System.Windows.Media.Animation.SizeKeyFrame to remove from the collection.
  """
  pass
 def RemoveAt(self,index):
  """
  RemoveAt(self: SizeKeyFrameCollection,index: int)

   Removes the System.Windows.Media.Animation.SizeKeyFrame at the specified index position from the 

    collection.

  

  

   index: Index position of the System.Windows.Media.Animation.SizeKeyFrame to be removed.
  """
  pass
 def ShouldSerializeProperty(self,*args):
  """
  ShouldSerializeProperty(self: DependencyObject,dp: DependencyProperty) -> bool

  

   Returns a value that indicates whether serialization processes should serialize the value for 

    the provided dependency property.

  

  

   dp: The identifier for the dependency property that should be serialized.

   Returns: true if the dependency property that is supplied should be value-serialized; otherwise,false.
  """
  pass
 def WritePostscript(self,*args):
  """
  WritePostscript(self: Freezable)

   Raises the System.Windows.Freezable.Changed event for the System.Windows.Freezable and invokes 

    its System.Windows.Freezable.OnChanged method. Classes that derive from System.Windows.Freezable 

    should call this method at the end of any API that modifies class members that are not stored as 

    dependency properties.
  """
  pass
 def WritePreamble(self,*args):
  """
  WritePreamble(self: Freezable)

   Verifies that the System.Windows.Freezable is not frozen and that it is being accessed from a 

    valid threading context. System.Windows.Freezable inheritors should call this method at the 

    beginning of any API that writes to data members that are not dependency properties.
  """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+y """
  pass
 def __contains__(self,*args):
  """
  __contains__(self: IList,value: object) -> bool

  

   Determines whether the System.Collections.IList contains a specific value.

  

   value: The object to locate in the System.Collections.IList.

   Returns: true if the System.Object is found in the System.Collections.IList; otherwise,false.
  """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y] """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 def __len__(self,*args):
  """ x.__len__() <==> len(x) """
  pass
 def __setitem__(self,*args):
  """ x.__setitem__(i,y) <==> x[i]= """
  pass
 Count=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the number of key frames contained in the System.Windows.Media.Animation.SizeKeyFrameCollection.



Get: Count(self: SizeKeyFrameCollection) -> int



"""

 IsFixedSize=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates if the collection size can ever change.



Get: IsFixedSize(self: SizeKeyFrameCollection) -> bool



"""

 IsReadOnly=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates if the collection is read-only.



Get: IsReadOnly(self: SizeKeyFrameCollection) -> bool



"""

 IsSynchronized=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates whether access to the collection is synchronized (thread-safe).



Get: IsSynchronized(self: SizeKeyFrameCollection) -> bool



"""

 SyncRoot=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets an object that can be used to synchronize access to the collection.



Get: SyncRoot(self: SizeKeyFrameCollection) -> object



"""


 Empty=None




class DllImportAttribute(Attribute,_Attribute):
 """
 Indicates that the attributed method is exposed by an unmanaged dynamic-link library (DLL) as a static entry point.

 

 DllImportAttribute(dllName: str)
 """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,dllName):
  """ __new__(cls: type,dllName: str) """
  pass
 Value=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the name of the DLL file that contains the entry point.



Get: Value(self: DllImportAttribute) -> str



"""


 BestFitMapping=None
 CallingConvention=None
 CharSet=None
 EntryPoint=None
 ExactSpelling=None
 PreserveSig=None
 SetLastError=None
 ThrowOnUnmappableChar=None




class NestedContainer(Container,IContainer,IDisposable,INestedContainer):
 """
 Provides the base implementation for the System.ComponentModel.INestedContainer interface,which enables containers to have an owning component.

 

 NestedContainer(owner: IComponent)
 """
 def CreateSite(self,*args):
  """
  CreateSite(self: NestedContainer,component: IComponent,name: str) -> ISite

  

   Creates a site for the component within the container.

  

   component: The System.ComponentModel.IComponent to create a site for.

   name: The name to assign to component,or null to skip the name assignment.

   Returns: The newly created System.ComponentModel.ISite.
  """
  pass
 def Dispose(self):
  """
  Dispose(self: NestedContainer,disposing: bool)

   Releases the resources used by the nested container.

  

   disposing: true to release both managed and unmanaged resources; false to release only unmanaged resources.
  """
  pass
 def GetService(self,*args):
  """
  GetService(self: NestedContainer,service: Type) -> object

  

   Gets the service object of the specified type,if it is available.

  

   service: The System.Type of the service to retrieve.

   Returns: An System.Object that implements the requested service,or null if the service cannot be 

    resolved.
  """
  pass
 def RemoveWithoutUnsiting(self,*args):
  """
  RemoveWithoutUnsiting(self: Container,component: IComponent)

   Removes a component from the System.ComponentModel.Container without setting 

    System.ComponentModel.IComponent.Site to null.

  

  

   component: The component to remove.
  """
  pass
 def ValidateName(self,*args):
  """
  ValidateName(self: Container,component: IComponent,name: str)

   Determines whether the component name is unique for this container.

  

   component: The named component.

   name: The component name to validate.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,owner):
  """ __new__(cls: type,owner: IComponent) """
  pass
 Owner=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the owning component for this nested container.



Get: Owner(self: NestedContainer) -> IComponent



"""

 OwnerName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the name of the owning component.



"""





class StatusBarPanelClickEventArgs(MouseEventArgs):
 """
 Provides data for the System.Windows.Forms.StatusBar.PanelClick event.

 

 StatusBarPanelClickEventArgs(statusBarPanel: StatusBarPanel,button: MouseButtons,clicks: int,x: int,y: int)
 """
 @staticmethod
 def __new__(self,statusBarPanel,button,clicks,x,y):
  """ __new__(cls: type,statusBarPanel: StatusBarPanel,button: MouseButtons,clicks: int,x: int,y: int) """
  pass
 StatusBarPanel=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Windows.Forms.StatusBarPanel to draw.



Get: StatusBarPanel(self: StatusBarPanelClickEventArgs) -> StatusBarPanel



"""





class ToolStripItem(Component,IComponent,IDisposable,IDropTarget,ISupportOleDropSource,IArrangedElement):
 """ Represents the abstract base class that manages events and layout for all the elements that a System.Windows.Forms.ToolStrip or System.Windows.Forms.ToolStripDropDown can contain. """
 def CreateAccessibilityInstance(self,*args):
  """
  CreateAccessibilityInstance(self: ToolStripItem) -> AccessibleObject

  

   Creates a new accessibility object for the System.Windows.Forms.ToolStripItem.

   Returns: A new System.Windows.Forms.AccessibleObject for the System.Windows.Forms.ToolStripItem.
  """
  pass
 def Dispose(self):
  """
  Dispose(self: ToolStripItem,disposing: bool)

   Releases the unmanaged resources used by the System.Windows.Forms.ToolStripItem and optionally 

    releases the managed resources.

  

  

   disposing: true to release both managed and unmanaged resources; false to release only unmanaged resources.
  """
  pass
 def DoDragDrop(self,data,allowedEffects):
  """
  DoDragDrop(self: ToolStripItem,data: object,allowedEffects: DragDropEffects) -> DragDropEffects

  

   Begins a drag-and-drop operation.

  

   data: The object to be dragged.

   allowedEffects: The drag operations that can occur.

   Returns: One of the System.Windows.Forms.DragDropEffects values.
  """
  pass
 def GetCurrentParent(self):
  """
  GetCurrentParent(self: ToolStripItem) -> ToolStrip

  

   Retrieves the System.Windows.Forms.ToolStrip that is the container of the current 

    System.Windows.Forms.ToolStripItem.

  

   Returns: A System.Windows.Forms.ToolStrip that is the container of the current 

    System.Windows.Forms.ToolStripItem.
  """
  pass
 def GetPreferredSize(self,constrainingSize):
  """
  GetPreferredSize(self: ToolStripItem,constrainingSize: Size) -> Size

  

   Retrieves the size of a rectangular area into which a control can be fit.

  

   constrainingSize: The custom-sized area for a control.

   Returns: A System.Drawing.Size ordered pair,representing the width and height of a rectangle.
  """
  pass
 def GetService(self,*args):
  """
  GetService(self: Component,service: Type) -> object

  

   Returns an object that represents a service provided by the System.ComponentModel.Component or 

    by its System.ComponentModel.Container.

  

  

   service: A service provided by the System.ComponentModel.Component.

   Returns: An System.Object that represents a service provided by the System.ComponentModel.Component,or 

    null if the System.ComponentModel.Component does not provide the specified service.
  """
  pass
 def Invalidate(self,r=None):
  """
  Invalidate(self: ToolStripItem,r: Rectangle)

   Invalidates the specified region of the System.Windows.Forms.ToolStripItem by adding it to the 

    update region of the System.Windows.Forms.ToolStripItem,which is the area that will be 

    repainted at the next paint operation,and causes a paint message to be sent to the 

    System.Windows.Forms.ToolStripItem.

  

  

   r: A System.Drawing.Rectangle that represents the region to invalidate.

  Invalidate(self: ToolStripItem)

   Invalidates the entire surface of the System.Windows.Forms.ToolStripItem and causes it to be 

    redrawn.
  """
  pass
 def IsInputChar(self,*args):
  """
  IsInputChar(self: ToolStripItem,charCode: Char) -> bool

  

   Determines whether a character is an input character that the item recognizes.

  

   charCode: The character to test.

   Returns: true if the character should be sent directly to the item and not preprocessed; otherwise,false.
  """
  pass
 def IsInputKey(self,*args):
  """
  IsInputKey(self: ToolStripItem,keyData: Keys) -> bool

  

   Determines whether the specified key is a regular input key or a special key that requires 

    preprocessing.

  

  

   keyData: One of the System.Windows.Forms.Keys values.

   Returns: true if the specified key is a regular input key; otherwise,false.
  """
  pass
 def MemberwiseClone(self,*args):
  """
  MemberwiseClone(self: MarshalByRefObject,cloneIdentity: bool) -> MarshalByRefObject

  

   Creates a shallow copy of the current System.MarshalByRefObject object.

  

   cloneIdentity: false to delete the current System.MarshalByRefObject object's identity,which will cause the 

    object to be assigned a new identity when it is marshaled across a remoting boundary. A value of 

    false is usually appropriate. true to copy the current System.MarshalByRefObject object's 

    identity to its clone,which will cause remoting client calls to be routed to the remote server 

    object.

  

   Returns: A shallow copy of the current System.MarshalByRefObject object.

  MemberwiseClone(self: object) -> object

  

   Creates a shallow copy of the current System.Object.

   Returns: A shallow copy of the current System.Object.
  """
  pass
 def OnAvailableChanged(self,*args):
  """
  OnAvailableChanged(self: ToolStripItem,e: EventArgs)

   Raises the AvailableChanged event.

  

   e: An System.EventArgs that contains the event data.
  """
  pass
 def OnBackColorChanged(self,*args):
  """
  OnBackColorChanged(self: ToolStripItem,e: EventArgs)

   Raises the System.Windows.Forms.ToolStripItem.BackColorChanged event.

  

   e: An System.EventArgs that contains the event data.
  """
  pass
 def OnBoundsChanged(self,*args):
  """
  OnBoundsChanged(self: ToolStripItem)

   Occurs when the System.Windows.Forms.ToolStripItem.Bounds property changes.
  """
  pass
 def OnClick(self,*args):
  """
  OnClick(self: ToolStripItem,e: EventArgs)

   Raises the System.Windows.Forms.ToolStripItem.Click event.

  

   e: An System.EventArgs that contains the event data.
  """
  pass
 def OnDisplayStyleChanged(self,*args):
  """
  OnDisplayStyleChanged(self: ToolStripItem,e: EventArgs)

   Raises the System.Windows.Forms.ToolStripItem.DisplayStyleChanged event.

  

   e: An System.EventArgs that contains the event data.
  """
  pass
 def OnDoubleClick(self,*args):
  """
  OnDoubleClick(self: ToolStripItem,e: EventArgs)

   Raises the System.Windows.Forms.ToolStripItem.DoubleClick event.

  

   e: An System.EventArgs that contains the event data.
  """
  pass
 def OnDragDrop(self,*args):
  """
  OnDragDrop(self: ToolStripItem,dragEvent: DragEventArgs)

   Raises the System.Windows.Forms.ToolStripItem.DragDrop event.

  

   dragEvent: A System.Windows.Forms.DragEventArgs that contains the event data.
  """
  pass
 def OnDragEnter(self,*args):
  """
  OnDragEnter(self: ToolStripItem,dragEvent: DragEventArgs)

   Raises the System.Windows.Forms.ToolStripItem.DragEnter event.

  

   dragEvent: A System.Windows.Forms.DragEventArgs that contains the event data.
  """
  pass
 def OnDragLeave(self,*args):
  """
  OnDragLeave(self: ToolStripItem,e: EventArgs)

   Raises the System.Windows.Forms.ToolStripItem.DragLeave event.

  

   e: An System.EventArgs that contains the event data.
  """
  pass
 def OnDragOver(self,*args):
  """
  OnDragOver(self: ToolStripItem,dragEvent: DragEventArgs)

   Raises the System.Windows.Forms.ToolStripItem.DragOver event.

  

   dragEvent: A System.Windows.Forms.DragEventArgs that contains the event data.
  """
  pass
 def OnEnabledChanged(self,*args):
  """
  OnEnabledChanged(self: ToolStripItem,e: EventArgs)

   Raises the System.Windows.Forms.ToolStripItem.EnabledChanged event.

  

   e: An System.EventArgs that contains the event data.
  """
  pass
 def OnFontChanged(self,*args):
  """
  OnFontChanged(self: ToolStripItem,e: EventArgs)

   Raises the System.Windows.Forms.Control.FontChanged event.

  

   e: An System.EventArgs that contains the event data.
  """
  pass
 def OnForeColorChanged(self,*args):
  """
  OnForeColorChanged(self: ToolStripItem,e: EventArgs)

   Raises the System.Windows.Forms.ToolStripItem.ForeColorChanged event.

  

   e: An System.EventArgs that contains the event data.
  """
  pass
 def OnGiveFeedback(self,*args):
  """
  OnGiveFeedback(self: ToolStripItem,giveFeedbackEvent: GiveFeedbackEventArgs)

   Raises the System.Windows.Forms.ToolStripItem.GiveFeedback event.

  

   giveFeedbackEvent: A System.Windows.Forms.GiveFeedbackEventArgs that contains the event data.
  """
  pass
 def OnLayout(self,*args):
  """
  OnLayout(self: ToolStripItem,e: LayoutEventArgs)

   Raises the System.Windows.Forms.Control.Layout event.

  

   e: A System.Windows.Forms.LayoutEventArgs that contains the event data.
  """
  pass
 def OnLocationChanged(self,*args):
  """
  OnLocationChanged(self: ToolStripItem,e: EventArgs)

   Raises the System.Windows.Forms.ToolStripItem.LocationChanged event.

  

   e: An System.EventArgs that contains the event data.
  """
  pass
 def OnMouseDown(self,*args):
  """
  OnMouseDown(self: ToolStripItem,e: MouseEventArgs)

   Raises the System.Windows.Forms.ToolStripItem.MouseDown event.

  

   e: A System.Windows.Forms.MouseEventArgs that contains the event data.
  """
  pass
 def OnMouseEnter(self,*args):
  """
  OnMouseEnter(self: ToolStripItem,e: EventArgs)

   Raises the System.Windows.Forms.ToolStripItem.MouseEnter event.

  

   e: An System.EventArgs that contains the event data.
  """
  pass
 def OnMouseHover(self,*args):
  """
  OnMouseHover(self: ToolStripItem,e: EventArgs)

   Raises the System.Windows.Forms.ToolStripItem.MouseHover event.

  

   e: An System.EventArgs that contains the event data.
  """
  pass
 def OnMouseLeave(self,*args):
  """
  OnMouseLeave(self: ToolStripItem,e: EventArgs)

   Raises the System.Windows.Forms.ToolStripItem.MouseLeave event.

  

   e: An System.EventArgs that contains the event data.
  """
  pass
 def OnMouseMove(self,*args):
  """
  OnMouseMove(self: ToolStripItem,mea: MouseEventArgs)

   Raises the System.Windows.Forms.ToolStripItem.MouseMove event.

  

   mea: A System.Windows.Forms.MouseEventArgs that contains the event data.
  """
  pass
 def OnMouseUp(self,*args):
  """
  OnMouseUp(self: ToolStripItem,e: MouseEventArgs)

   Raises the System.Windows.Forms.ToolStripItem.MouseUp event.

  

   e: A System.Windows.Forms.MouseEventArgs that contains the event data.
  """
  pass
 def OnOwnerChanged(self,*args):
  """
  OnOwnerChanged(self: ToolStripItem,e: EventArgs)

   Raises the System.Windows.Forms.ToolStripItem.OwnerChanged event.

  

   e: An System.EventArgs that contains the event data.
  """
  pass
 def OnOwnerFontChanged(self,*args):
  """
  OnOwnerFontChanged(self: ToolStripItem,e: EventArgs)

   Raises the System.Windows.Forms.Control.FontChanged event when the 

    System.Windows.Forms.ToolStripItem.Font property has changed on the parent of the 

    System.Windows.Forms.ToolStripItem.

  

  

   e: A System.EventArgs that contains the event data.
  """
  pass
 def OnPaint(self,*args):
  """
  OnPaint(self: ToolStripItem,e: PaintEventArgs)

   Raises the System.Windows.Forms.ToolStripItem.Paint event.

  

   e: A System.Windows.Forms.PaintEventArgs that contains the event data.
  """
  pass
 def OnParentBackColorChanged(self,*args):
  """
  OnParentBackColorChanged(self: ToolStripItem,e: EventArgs)

   Raises the System.Windows.Forms.ToolStripItem.BackColorChanged event.

  

   e: An System.EventArgs that contains the event data.
  """
  pass
 def OnParentChanged(self,*args):
  """
  OnParentChanged(self: ToolStripItem,oldParent: ToolStrip,newParent: ToolStrip)

   Raises the System.Windows.Forms.Control.ParentChanged event.

  

   oldParent: The original parent of the item.

   newParent: The new parent of the item.
  """
  pass
 def OnParentEnabledChanged(self,*args):
  """
  OnParentEnabledChanged(self: ToolStripItem,e: EventArgs)

   Raises the System.Windows.Forms.ToolStripItem.EnabledChanged event when the 

    System.Windows.Forms.ToolStripItem.Enabled property value of the item's container changes.

  

  

   e: An System.EventArgs that contains the event data.
  """
  pass
 def OnParentForeColorChanged(self,*args):
  """
  OnParentForeColorChanged(self: ToolStripItem,e: EventArgs)

   Raises the System.Windows.Forms.ToolStripItem.ForeColorChanged event.

  

   e: An System.EventArgs that contains the event data.
  """
  pass
 def OnParentRightToLeftChanged(self,*args):
  """
  OnParentRightToLeftChanged(self: ToolStripItem,e: EventArgs)

   Raises the System.Windows.Forms.ToolStripItem.RightToLeftChanged event.

  

   e: An System.EventArgs that contains the event data.
  """
  pass
 def OnQueryContinueDrag(self,*args):
  """
  OnQueryContinueDrag(self: ToolStripItem,queryContinueDragEvent: QueryContinueDragEventArgs)

   Raises the System.Windows.Forms.ToolStripItem.QueryContinueDrag event.

  

   queryContinueDragEvent: A System.Windows.Forms.QueryContinueDragEventArgs that contains the event data.
  """
  pass
 def OnRightToLeftChanged(self,*args):
  """
  OnRightToLeftChanged(self: ToolStripItem,e: EventArgs)

   Raises the System.Windows.Forms.ToolStripItem.RightToLeftChanged event.

  

   e: An System.EventArgs that contains the event data.
  """
  pass
 def OnTextChanged(self,*args):
  """
  OnTextChanged(self: ToolStripItem,e: EventArgs)

   Raises the System.Windows.Forms.ToolStripItem.TextChanged event.

  

   e: An System.EventArgs that contains the event data.
  """
  pass
 def OnVisibleChanged(self,*args):
  """
  OnVisibleChanged(self: ToolStripItem,e: EventArgs)

   Raises the System.Windows.Forms.ToolStripItem.VisibleChanged event.

  

   e: An System.EventArgs that contains the event data.
  """
  pass
 def PerformClick(self):
  """
  PerformClick(self: ToolStripItem)

   Activates the System.Windows.Forms.ToolStripItem when it is clicked with the mouse.
  """
  pass
 def ProcessCmdKey(self,*args):
  """
  ProcessCmdKey(self: ToolStripItem,m: Message,keyData: Keys) -> (bool,Message)

  

   Processes a command key.

  

   m: A System.Windows.Forms.Message,passed by reference,that represents the window message to 

    process.

  

   keyData: One of the System.Windows.Forms.Keys values that represents the key to process.

   Returns: false in all cases.
  """
  pass
 def ProcessDialogKey(self,*args):
  """
  ProcessDialogKey(self: ToolStripItem,keyData: Keys) -> bool

  

   Processes a dialog key.

  

   keyData: One of the System.Windows.Forms.Keys values that represents the key to process.

   Returns: true if the key was processed by the item; otherwise,false.
  """
  pass
 def ProcessMnemonic(self,*args):
  """
  ProcessMnemonic(self: ToolStripItem,charCode: Char) -> bool

  

   Processes a mnemonic character.

  

   charCode: The character to process.

   Returns: true in all cases.
  """
  pass
 def ResetBackColor(self):
  """
  ResetBackColor(self: ToolStripItem)

   This method is not relevant to this class.
  """
  pass
 def ResetDisplayStyle(self):
  """
  ResetDisplayStyle(self: ToolStripItem)

   This method is not relevant to this class.
  """
  pass
 def ResetFont(self):
  """
  ResetFont(self: ToolStripItem)

   This method is not relevant to this class.
  """
  pass
 def ResetForeColor(self):
  """
  ResetForeColor(self: ToolStripItem)

   This method is not relevant to this class.
  """
  pass
 def ResetImage(self):
  """
  ResetImage(self: ToolStripItem)

   This method is not relevant to this class.
  """
  pass
 def ResetMargin(self):
  """
  ResetMargin(self: ToolStripItem)

   This method is not relevant to this class.
  """
  pass
 def ResetPadding(self):
  """
  ResetPadding(self: ToolStripItem)

   This method is not relevant to this class.
  """
  pass
 def ResetRightToLeft(self):
  """
  ResetRightToLeft(self: ToolStripItem)

   This method is not relevant to this class.
  """
  pass
 def ResetTextDirection(self):
  """
  ResetTextDirection(self: ToolStripItem)

   This method is not relevant to this class.
  """
  pass
 def Select(self):
  """
  Select(self: ToolStripItem)

   Selects the item.
  """
  pass
 def SetBounds(self,*args):
  """
  SetBounds(self: ToolStripItem,bounds: Rectangle)

   Sets the size and location of the item.

  

   bounds: A System.Drawing.Rectangle that represents the size and location of the 

    System.Windows.Forms.ToolStripItem
  """
  pass
 def SetVisibleCore(self,*args):
  """
  SetVisibleCore(self: ToolStripItem,visible: bool)

   Sets the System.Windows.Forms.ToolStripItem to the specified visible state.

  

   visible: true to make the System.Windows.Forms.ToolStripItem visible; otherwise,false.
  """
  pass
 def ToString(self):
  """
  ToString(self: ToolStripItem) -> str

   Returns: A System.String containing the name of the System.ComponentModel.Component,if any,or null if 

    the System.ComponentModel.Component is unnamed.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,*args): #cannot find CLR constructor
  """
  __new__(cls: type)

  __new__(cls: type,text: str,image: Image,onClick: EventHandler)

  __new__(cls: type,text: str,image: Image,onClick: EventHandler,name: str)
  """
  pass
 def __str__(self,*args):
  pass
 AccessibilityObject=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Windows.Forms.AccessibleObject assigned to the control.



Get: AccessibilityObject(self: ToolStripItem) -> AccessibleObject



"""

 AccessibleDefaultActionDescription=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the default action description of the control for use by accessibility client applications.



Get: AccessibleDefaultActionDescription(self: ToolStripItem) -> str



Set: AccessibleDefaultActionDescription(self: ToolStripItem)=value

"""

 AccessibleDescription=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the description that will be reported to accessibility client applications.



Get: AccessibleDescription(self: ToolStripItem) -> str



Set: AccessibleDescription(self: ToolStripItem)=value

"""

 AccessibleName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the name of the control for use by accessibility client applications.



Get: AccessibleName(self: ToolStripItem) -> str



Set: AccessibleName(self: ToolStripItem)=value

"""

 AccessibleRole=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the accessible role of the control,which specifies the type of user interface element of the control.



Get: AccessibleRole(self: ToolStripItem) -> AccessibleRole



Set: AccessibleRole(self: ToolStripItem)=value

"""

 Alignment=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the item aligns towards the beginning or end of the System.Windows.Forms.ToolStrip.



Get: Alignment(self: ToolStripItem) -> ToolStripItemAlignment



Set: Alignment(self: ToolStripItem)=value

"""

 AllowDrop=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether drag-and-drop and item reordering are handled through events that you implement.



Get: AllowDrop(self: ToolStripItem) -> bool



Set: AllowDrop(self: ToolStripItem)=value

"""

 Anchor=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the edges of the container to which a System.Windows.Forms.ToolStripItem is bound and determines how a System.Windows.Forms.ToolStripItem  is resized with its parent.



Get: Anchor(self: ToolStripItem) -> AnchorStyles



Set: Anchor(self: ToolStripItem)=value

"""

 AutoSize=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the item is automatically sized.



Get: AutoSize(self: ToolStripItem) -> bool



Set: AutoSize(self: ToolStripItem)=value

"""

 AutoToolTip=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether to use the System.Windows.Forms.ToolStripItem.Text property or the System.Windows.Forms.ToolStripItem.ToolTipText property for the System.Windows.Forms.ToolStripItem ToolTip.



Get: AutoToolTip(self: ToolStripItem) -> bool



Set: AutoToolTip(self: ToolStripItem)=value

"""

 Available=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the System.Windows.Forms.ToolStripItem should be placed on a System.Windows.Forms.ToolStrip.



Get: Available(self: ToolStripItem) -> bool



Set: Available(self: ToolStripItem)=value

"""

 BackColor=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the background color for the item.



Get: BackColor(self: ToolStripItem) -> Color



Set: BackColor(self: ToolStripItem)=value

"""

 BackgroundImage=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the background image displayed in the item.



Get: BackgroundImage(self: ToolStripItem) -> Image



Set: BackgroundImage(self: ToolStripItem)=value

"""

 BackgroundImageLayout=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the background image layout used for the System.Windows.Forms.ToolStripItem.



Get: BackgroundImageLayout(self: ToolStripItem) -> ImageLayout



Set: BackgroundImageLayout(self: ToolStripItem)=value

"""

 Bounds=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the size and location of the item.



Get: Bounds(self: ToolStripItem) -> Rectangle



"""

 CanRaiseEvents=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the component can raise an event.



"""

 CanSelect=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the item can be selected.



Get: CanSelect(self: ToolStripItem) -> bool



"""

 ContentRectangle=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the area where content,such as text and icons,can be placed within a System.Windows.Forms.ToolStripItem without overwriting background borders.



Get: ContentRectangle(self: ToolStripItem) -> Rectangle



"""

 DefaultAutoToolTip=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether to display the System.Windows.Forms.ToolTip that is defined as the default.



"""

 DefaultDisplayStyle=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating what is displayed on the System.Windows.Forms.ToolStripItem.



"""

 DefaultMargin=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the default margin of an item.



"""

 DefaultPadding=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the internal spacing characteristics of the item.



"""

 DefaultSize=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the default size of the item.



"""

 DesignMode=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates whether the System.ComponentModel.Component is currently in design mode.



"""

 DismissWhenClicked=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether items on a System.Windows.Forms.ToolStripDropDown are hidden after they are clicked.



"""

 DisplayStyle=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets whether text and images are displayed on a System.Windows.Forms.ToolStripItem.



Get: DisplayStyle(self: ToolStripItem) -> ToolStripItemDisplayStyle



Set: DisplayStyle(self: ToolStripItem)=value

"""

 Dock=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets which System.Windows.Forms.ToolStripItem borders are docked to its parent control and determines how a System.Windows.Forms.ToolStripItem is resized with its parent.



Get: Dock(self: ToolStripItem) -> DockStyle



Set: Dock(self: ToolStripItem)=value

"""

 DoubleClickEnabled=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the System.Windows.Forms.ToolStripItem can be activated by double-clicking the mouse.



Get: DoubleClickEnabled(self: ToolStripItem) -> bool



Set: DoubleClickEnabled(self: ToolStripItem)=value

"""

 Enabled=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the parent control of the System.Windows.Forms.ToolStripItem is enabled.



Get: Enabled(self: ToolStripItem) -> bool



Set: Enabled(self: ToolStripItem)=value

"""

 Events=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the list of event handlers that are attached to this System.ComponentModel.Component.



"""

 Font=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the font of the text displayed by the item.



Get: Font(self: ToolStripItem) -> Font



Set: Font(self: ToolStripItem)=value

"""

 ForeColor=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the foreground color of the item.



Get: ForeColor(self: ToolStripItem) -> Color



Set: ForeColor(self: ToolStripItem)=value

"""

 Height=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the height,in pixels,of a System.Windows.Forms.ToolStripItem.



Get: Height(self: ToolStripItem) -> int



Set: Height(self: ToolStripItem)=value

"""

 Image=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the image that is displayed on a System.Windows.Forms.ToolStripItem.



Get: Image(self: ToolStripItem) -> Image



Set: Image(self: ToolStripItem)=value

"""

 ImageAlign=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the alignment of the image on a System.Windows.Forms.ToolStripItem.



Get: ImageAlign(self: ToolStripItem) -> ContentAlignment



Set: ImageAlign(self: ToolStripItem)=value

"""

 ImageIndex=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the index value of the image that is displayed on the item.



Get: ImageIndex(self: ToolStripItem) -> int



Set: ImageIndex(self: ToolStripItem)=value

"""

 ImageKey=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the key accessor for the image in the System.Windows.Forms.ToolStrip.ImageList that is displayed on a System.Windows.Forms.ToolStripItem.



Get: ImageKey(self: ToolStripItem) -> str



Set: ImageKey(self: ToolStripItem)=value

"""

 ImageScaling=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether an image on a System.Windows.Forms.ToolStripItem is automatically resized to fit in a container.



Get: ImageScaling(self: ToolStripItem) -> ToolStripItemImageScaling



Set: ImageScaling(self: ToolStripItem)=value

"""

 ImageTransparentColor=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the color to treat as transparent in a System.Windows.Forms.ToolStripItem image.



Get: ImageTransparentColor(self: ToolStripItem) -> Color



Set: ImageTransparentColor(self: ToolStripItem)=value

"""

 IsDisposed=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the object has been disposed of.



Get: IsDisposed(self: ToolStripItem) -> bool



"""

 IsOnDropDown=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the container of the current System.Windows.Forms.Control is a System.Windows.Forms.ToolStripDropDown.



Get: IsOnDropDown(self: ToolStripItem) -> bool



"""

 IsOnOverflow=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the System.Windows.Forms.ToolStripItem.Placement property is set to System.Windows.Forms.ToolStripItemPlacement.Overflow.



Get: IsOnOverflow(self: ToolStripItem) -> bool



"""

 Margin=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the space between the item and adjacent items.



Get: Margin(self: ToolStripItem) -> Padding



Set: Margin(self: ToolStripItem)=value

"""

 MergeAction=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets how child menus are merged with parent menus.



Get: MergeAction(self: ToolStripItem) -> MergeAction



Set: MergeAction(self: ToolStripItem)=value

"""

 MergeIndex=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the position of a merged item within the current System.Windows.Forms.ToolStrip.



Get: MergeIndex(self: ToolStripItem) -> int



Set: MergeIndex(self: ToolStripItem)=value

"""

 Name=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the name of the item.



Get: Name(self: ToolStripItem) -> str



Set: Name(self: ToolStripItem)=value

"""

 Overflow=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets whether the item is attached to the System.Windows.Forms.ToolStrip or System.Windows.Forms.ToolStripOverflowButton or can float between the two.



Get: Overflow(self: ToolStripItem) -> ToolStripItemOverflow



Set: Overflow(self: ToolStripItem)=value

"""

 Owner=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the owner of this item.



Get: Owner(self: ToolStripItem) -> ToolStrip



Set: Owner(self: ToolStripItem)=value

"""

 OwnerItem=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the parent System.Windows.Forms.ToolStripItem of this System.Windows.Forms.ToolStripItem.



Get: OwnerItem(self: ToolStripItem) -> ToolStripItem



"""

 Padding=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the internal spacing,in pixels,between the item's contents and its edges.



Get: Padding(self: ToolStripItem) -> Padding



Set: Padding(self: ToolStripItem)=value

"""

 Parent=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the parent container of the System.Windows.Forms.ToolStripItem.



"""

 Placement=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the current layout of the item.



Get: Placement(self: ToolStripItem) -> ToolStripItemPlacement



"""

 Pressed=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the state of the item is pressed.



Get: Pressed(self: ToolStripItem) -> bool



"""

 RightToLeft=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether items are to be placed from right to left and text is to be written from right to left.



Get: RightToLeft(self: ToolStripItem) -> RightToLeft



Set: RightToLeft(self: ToolStripItem)=value

"""

 RightToLeftAutoMirrorImage=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Mirrors automatically the System.Windows.Forms.ToolStripItem image when the System.Windows.Forms.ToolStripItem.RightToLeft property is set to System.Windows.Forms.RightToLeft.Yes.



Get: RightToLeftAutoMirrorImage(self: ToolStripItem) -> bool



Set: RightToLeftAutoMirrorImage(self: ToolStripItem)=value

"""

 Selected=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the item is selected.



Get: Selected(self: ToolStripItem) -> bool



"""

 ShowKeyboardCues=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether to show or hide shortcut keys.



"""

 Size=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the size of the item.



Get: Size(self: ToolStripItem) -> Size



Set: Size(self: ToolStripItem)=value

"""

 Tag=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the object that contains data about the item.



Get: Tag(self: ToolStripItem) -> object



Set: Tag(self: ToolStripItem)=value

"""

 Text=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the text that is to be displayed on the item.



Get: Text(self: ToolStripItem) -> str



Set: Text(self: ToolStripItem)=value

"""

 TextAlign=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the alignment of the text on a System.Windows.Forms.ToolStripLabel.



Get: TextAlign(self: ToolStripItem) -> ContentAlignment



Set: TextAlign(self: ToolStripItem)=value

"""

 TextDirection=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the orientation of text used on a System.Windows.Forms.ToolStripItem.



Get: TextDirection(self: ToolStripItem) -> ToolStripTextDirection



Set: TextDirection(self: ToolStripItem)=value

"""

 TextImageRelation=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the position of System.Windows.Forms.ToolStripItem text and image relative to each other.



Get: TextImageRelation(self: ToolStripItem) -> TextImageRelation



Set: TextImageRelation(self: ToolStripItem)=value

"""

 ToolTipText=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the text that appears as a System.Windows.Forms.ToolTip for a control.



Get: ToolTipText(self: ToolStripItem) -> str



Set: ToolTipText(self: ToolStripItem)=value

"""

 Visible=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a value indicating whether the item is displayed.



Get: Visible(self: ToolStripItem) -> bool



Set: Visible(self: ToolStripItem)=value

"""

 Width=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the width in pixels of a System.Windows.Forms.ToolStripItem.



Get: Width(self: ToolStripItem) -> int



Set: Width(self: ToolStripItem)=value

"""


 AvailableChanged=None
 BackColorChanged=None
 Click=None
 DisplayStyleChanged=None
 DoubleClick=None
 DragDrop=None
 DragEnter=None
 DragLeave=None
 DragOver=None
 EnabledChanged=None
 ForeColorChanged=None
 GiveFeedback=None
 LocationChanged=None
 MouseDown=None
 MouseEnter=None
 MouseHover=None
 MouseLeave=None
 MouseMove=None
 MouseUp=None
 OwnerChanged=None
 Paint=None
 QueryAccessibilityHelp=None
 QueryContinueDrag=None
 RightToLeftChanged=None
 TextChanged=None
 ToolStripItemAccessibleObject=None
 VisibleChanged=None




class Rectangle(object):
 """
 Stores a set of four integers that represent the location and size of a rectangle

 

 Rectangle(x: int,y: int,width: int,height: int)

 Rectangle(location: Point,size: Size)
 """
 @staticmethod
 def Ceiling(value):
  """
  Ceiling(value: RectangleF) -> Rectangle

  

   Converts the specified System.Drawing.RectangleF structure to a System.Drawing.Rectangle 

    structure by rounding the System.Drawing.RectangleF values to the next higher integer values.

  

  

   value: The System.Drawing.RectangleF structure to be converted.

   Returns: Returns a System.Drawing.Rectangle.
  """
  pass
 def Contains(self,*__args):
  """
  Contains(self: Rectangle,rect: Rectangle) -> bool

  

   Determines if the rectangular region represented by rect is entirely contained within this 

    System.Drawing.Rectangle structure.

  

  

   rect: The System.Drawing.Rectangle to test.

   Returns: This method returns true if the rectangular region represented by rect is entirely contained 

    within this System.Drawing.Rectangle structure; otherwise false.

  

  Contains(self: Rectangle,pt: Point) -> bool

  

   Determines if the specified point is contained within this System.Drawing.Rectangle structure.

  

   pt: The System.Drawing.Point to test.

   Returns: This method returns true if the point represented by pt is contained within this 

    System.Drawing.Rectangle structure; otherwise false.

  

  Contains(self: Rectangle,x: int,y: int) -> bool

  

   Determines if the specified point is contained within this System.Drawing.Rectangle structure.

  

   x: The x-coordinate of the point to test.

   y: The y-coordinate of the point to test.

   Returns: This method returns true if the point defined by x and y is contained within this 

    System.Drawing.Rectangle structure; otherwise false.
  """
  pass
 def Equals(self,obj):
  """
  Equals(self: Rectangle,obj: object) -> bool

  

   Tests whether obj is a System.Drawing.Rectangle structure with the same location and size of 

    this System.Drawing.Rectangle structure.

  

  

   obj: The System.Object to test.

   Returns: This method returns true if obj is a System.Drawing.Rectangle structure and its 

    System.Drawing.Rectangle.X,System.Drawing.Rectangle.Y,System.Drawing.Rectangle.Width,and 

    System.Drawing.Rectangle.Height properties are equal to the corresponding properties of this 

    System.Drawing.Rectangle structure; otherwise,false.
  """
  pass
 @staticmethod
 def FromLTRB(left,top,right,bottom):
  """
  FromLTRB(left: int,top: int,right: int,bottom: int) -> Rectangle

  

   Creates a System.Drawing.Rectangle structure with the specified edge locations.

  

   left: The x-coordinate of the upper-left corner of this System.Drawing.Rectangle structure.

   top: The y-coordinate of the upper-left corner of this System.Drawing.Rectangle structure.

   right: The x-coordinate of the lower-right corner of this System.Drawing.Rectangle structure.

   bottom: The y-coordinate of the lower-right corner of this System.Drawing.Rectangle structure.

   Returns: The new System.Drawing.Rectangle that this method creates.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: Rectangle) -> int

  

   Returns the hash code for this System.Drawing.Rectangle structure. For information about the use 

    of hash codes,see System.Object.GetHashCode .

  

   Returns: An integer that represents the hash code for this rectangle.
  """
  pass
 def Inflate(self,*__args):
  """
  Inflate(rect: Rectangle,x: int,y: int) -> Rectangle

  

   Creates and returns an enlarged copy of the specified System.Drawing.Rectangle structure. The 

    copy is enlarged by the specified amount. The original System.Drawing.Rectangle structure 

    remains unmodified.

  

  

   rect: The System.Drawing.Rectangle with which to start. This rectangle is not modified.

   x: The amount to inflate this System.Drawing.Rectangle horizontally.

   y: The amount to inflate this System.Drawing.Rectangle vertically.

   Returns: The enlarged System.Drawing.Rectangle.

  Inflate(self: Rectangle,size: Size)

   Enlarges this System.Drawing.Rectangle by the specified amount.

  

   size: The amount to inflate this rectangle.

  Inflate(self: Rectangle,width: int,height: int)

   Enlarges this System.Drawing.Rectangle by the specified amount.

  

   width: The amount to inflate this System.Drawing.Rectangle horizontally.

   height: The amount to inflate this System.Drawing.Rectangle vertically.
  """
  pass
 def Intersect(self,*__args):
  """
  Intersect(a: Rectangle,b: Rectangle) -> Rectangle

  

   Returns a third System.Drawing.Rectangle structure that represents the intersection of two other 

    System.Drawing.Rectangle structures. If there is no intersection,an empty 

    System.Drawing.Rectangle is returned.

  

  

   a: A rectangle to intersect.

   b: A rectangle to intersect.

   Returns: A System.Drawing.Rectangle that represents the intersection of a and b.

  Intersect(self: Rectangle,rect: Rectangle)

   Replaces this System.Drawing.Rectangle with the intersection of itself and the specified 

    System.Drawing.Rectangle.

  

  

   rect: The System.Drawing.Rectangle with which to intersect.
  """
  pass
 def IntersectsWith(self,rect):
  """
  IntersectsWith(self: Rectangle,rect: Rectangle) -> bool

  

   Determines if this rectangle intersects with rect.

  

   rect: The rectangle to test.

   Returns: This method returns true if there is any intersection,otherwise false.
  """
  pass
 def Offset(self,*__args):
  """
  Offset(self: Rectangle,x: int,y: int)

   Adjusts the location of this rectangle by the specified amount.

  

   x: The horizontal offset.

   y: The vertical offset.

  Offset(self: Rectangle,pos: Point)

   Adjusts the location of this rectangle by the specified amount.

  

   pos: Amount to offset the location.
  """
  pass
 @staticmethod
 def Round(value):
  """
  Round(value: RectangleF) -> Rectangle

  

   Converts the specified System.Drawing.RectangleF to a System.Drawing.Rectangle by rounding the 

    System.Drawing.RectangleF values to the nearest integer values.

  

  

   value: The System.Drawing.RectangleF to be converted.

   Returns: A System.Drawing.Rectangle.
  """
  pass
 def ToString(self):
  """
  ToString(self: Rectangle) -> str

  

   Converts the attributes of this System.Drawing.Rectangle to a human-readable string.

   Returns: A string that contains the position,width,and height of this System.Drawing.Rectangle 

    structure � for example,{X=20,Y=20,Width=100,Height=50}
  """
  pass
 @staticmethod
 def Truncate(value):
  """
  Truncate(value: RectangleF) -> Rectangle

  

   Converts the specified System.Drawing.RectangleF to a System.Drawing.Rectangle by truncating the 

    System.Drawing.RectangleF values.

  

  

   value: The System.Drawing.RectangleF to be converted.

   Returns: A System.Drawing.Rectangle.
  """
  pass
 @staticmethod
 def Union(a,b):
  """
  Union(a: Rectangle,b: Rectangle) -> Rectangle

  

   Gets a System.Drawing.Rectangle structure that contains the union of two 

    System.Drawing.Rectangle structures.

  

  

   a: A rectangle to union.

   b: A rectangle to union.

   Returns: A System.Drawing.Rectangle structure that bounds the union of the two System.Drawing.Rectangle 

    structures.
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__[Rectangle]() -> Rectangle

  

  __new__(cls: type,x: int,y: int,width: int,height: int)

  __new__(cls: type,location: Point,size: Size)
  """
  pass
 def __ne__(self,*args):
  pass
 Bottom=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the y-coordinate that is the sum of the System.Drawing.Rectangle.Y and System.Drawing.Rectangle.Height property values of this System.Drawing.Rectangle structure.



Get: Bottom(self: Rectangle) -> int



"""

 Height=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the height of this System.Drawing.Rectangle structure.



Get: Height(self: Rectangle) -> int



Set: Height(self: Rectangle)=value

"""

 IsEmpty=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Tests whether all numeric properties of this System.Drawing.Rectangle have values of zero.



Get: IsEmpty(self: Rectangle) -> bool



"""

 Left=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the x-coordinate of the left edge of this System.Drawing.Rectangle structure.



Get: Left(self: Rectangle) -> int



"""

 Location=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the coordinates of the upper-left corner of this System.Drawing.Rectangle structure.



Get: Location(self: Rectangle) -> Point



Set: Location(self: Rectangle)=value

"""

 Right=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the x-coordinate that is the sum of System.Drawing.Rectangle.X and System.Drawing.Rectangle.Width property values of this System.Drawing.Rectangle structure.



Get: Right(self: Rectangle) -> int



"""

 Size=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the size of this System.Drawing.Rectangle.



Get: Size(self: Rectangle) -> Size



Set: Size(self: Rectangle)=value

"""

 Top=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the y-coordinate of the top edge of this System.Drawing.Rectangle structure.



Get: Top(self: Rectangle) -> int



"""

 Width=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the width of this System.Drawing.Rectangle structure.



Get: Width(self: Rectangle) -> int



Set: Width(self: Rectangle)=value

"""

 X=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the x-coordinate of the upper-left corner of this System.Drawing.Rectangle structure.



Get: X(self: Rectangle) -> int



Set: X(self: Rectangle)=value

"""

 Y=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the y-coordinate of the upper-left corner of this System.Drawing.Rectangle structure.



Get: Y(self: Rectangle) -> int



Set: Y(self: Rectangle)=value

"""


 Empty=None




class FileSystemAccessRule(AccessRule):
 """
 Represents an abstraction of an access control entry (ACE) that defines an access rule for a file or directory. This class cannot be inherited.

 

 FileSystemAccessRule(identity: IdentityReference,fileSystemRights: FileSystemRights,type: AccessControlType)

 FileSystemAccessRule(identity: str,fileSystemRights: FileSystemRights,type: AccessControlType)

 FileSystemAccessRule(identity: IdentityReference,fileSystemRights: FileSystemRights,inheritanceFlags: InheritanceFlags,propagationFlags: PropagationFlags,type: AccessControlType)

 FileSystemAccessRule(identity: str,fileSystemRights: FileSystemRights,inheritanceFlags: InheritanceFlags,propagationFlags: PropagationFlags,type: AccessControlType)
 """
 @staticmethod
 def __new__(self,identity,fileSystemRights,*__args):
  """
  __new__(cls: type,identity: IdentityReference,fileSystemRights: FileSystemRights,type: AccessControlType)

  __new__(cls: type,identity: str,fileSystemRights: FileSystemRights,type: AccessControlType)

  __new__(cls: type,identity: IdentityReference,fileSystemRights: FileSystemRights,inheritanceFlags: InheritanceFlags,propagationFlags: PropagationFlags,type: AccessControlType)

  __new__(cls: type,identity: str,fileSystemRights: FileSystemRights,inheritanceFlags: InheritanceFlags,propagationFlags: PropagationFlags,type: AccessControlType)
  """
  pass
 AccessMask=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the access mask for this rule.



"""

 FileSystemRights=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Security.AccessControl.FileSystemRights flags associated with the current System.Security.AccessControl.FileSystemAccessRule object.



Get: FileSystemRights(self: FileSystemAccessRule) -> FileSystemRights



"""





class FontFamily(MarshalByRefObject,IDisposable):
 """
 Defines a group of type faces having a similar basic design and certain variations in styles. This class cannot be inherited.

 

 FontFamily(name: str)

 FontFamily(name: str,fontCollection: FontCollection)

 FontFamily(genericFamily: GenericFontFamilies)
 """
 def Dispose(self):
  """
  Dispose(self: FontFamily)

   Releases all resources used by this System.Drawing.FontFamily.
  """
  pass
 def Equals(self,obj):
  """
  Equals(self: FontFamily,obj: object) -> bool

  

   Indicates whether the specified object is a System.Drawing.FontFamily and is identical to this 

    System.Drawing.FontFamily.

  

  

   obj: The object to test.

   Returns: true if obj is a System.Drawing.FontFamily and is identical to this System.Drawing.FontFamily; 

    otherwise,false.
  """
  pass
 def GetCellAscent(self,style):
  """
  GetCellAscent(self: FontFamily,style: FontStyle) -> int

  

   Returns the cell ascent,in design units,of the System.Drawing.FontFamily of the specified 

    style.

  

  

   style: A System.Drawing.FontStyle that contains style information for the font.

   Returns: The cell ascent for this System.Drawing.FontFamily that uses the specified 

    System.Drawing.FontStyle.
  """
  pass
 def GetCellDescent(self,style):
  """
  GetCellDescent(self: FontFamily,style: FontStyle) -> int

  

   Returns the cell descent,in design units,of the System.Drawing.FontFamily of the specified 

    style.

  

  

   style: A System.Drawing.FontStyle that contains style information for the font.

   Returns: The cell descent metric for this System.Drawing.FontFamily that uses the specified 

    System.Drawing.FontStyle.
  """
  pass
 def GetEmHeight(self,style):
  """
  GetEmHeight(self: FontFamily,style: FontStyle) -> int

  

   Gets the height,in font design units,of the em square for the specified style.

  

   style: The System.Drawing.FontStyle for which to get the em height.

   Returns: The height of the em square.
  """
  pass
 @staticmethod
 def GetFamilies(graphics):
  """
  GetFamilies(graphics: Graphics) -> Array[FontFamily]

  

   Returns an array that contains all the System.Drawing.FontFamily objects available for the 

    specified graphics context.

  

  

   graphics: The System.Drawing.Graphics object from which to return System.Drawing.FontFamily objects.

   Returns: An array of System.Drawing.FontFamily objects available for the specified 

    System.Drawing.Graphics object.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: FontFamily) -> int

  

   Gets a hash code for this System.Drawing.FontFamily.

   Returns: The hash code for this System.Drawing.FontFamily.
  """
  pass
 def GetLineSpacing(self,style):
  """
  GetLineSpacing(self: FontFamily,style: FontStyle) -> int

  

   Returns the line spacing,in design units,of the System.Drawing.FontFamily of the specified 

    style. The line spacing is the vertical distance between the base lines of two consecutive lines 

    of text.

  

  

   style: The System.Drawing.FontStyle to apply.

   Returns: The distance between two consecutive lines of text.
  """
  pass
 def GetName(self,language):
  """
  GetName(self: FontFamily,language: int) -> str

  

   Returns the name,in the specified language,of this System.Drawing.FontFamily.

  

   language: The language in which the name is returned.

   Returns: A System.String that represents the name,in the specified language,of this 

    System.Drawing.FontFamily.
  """
  pass
 def IsStyleAvailable(self,style):
  """
  IsStyleAvailable(self: FontFamily,style: FontStyle) -> bool

  

   Indicates whether the specified System.Drawing.FontStyle enumeration is available.

  

   style: The System.Drawing.FontStyle to test.

   Returns: true if the specified System.Drawing.FontStyle is available; otherwise,false.
  """
  pass
 def MemberwiseClone(self,*args):
  """
  MemberwiseClone(self: MarshalByRefObject,cloneIdentity: bool) -> MarshalByRefObject

  

   Creates a shallow copy of the current System.MarshalByRefObject object.

  

   cloneIdentity: false to delete the current System.MarshalByRefObject object's identity,which will cause the 

    object to be assigned a new identity when it is marshaled across a remoting boundary. A value of 

    false is usually appropriate. true to copy the current System.MarshalByRefObject object's 

    identity to its clone,which will cause remoting client calls to be routed to the remote server 

    object.

  

   Returns: A shallow copy of the current System.MarshalByRefObject object.

  MemberwiseClone(self: object) -> object

  

   Creates a shallow copy of the current System.Object.

   Returns: A shallow copy of the current System.Object.
  """
  pass
 def ToString(self):
  """
  ToString(self: FontFamily) -> str

  

   Converts this System.Drawing.FontFamily to a human-readable string representation.

   Returns: The string that represents this System.Drawing.FontFamily.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type,name: str)

  __new__(cls: type,name: str,fontCollection: FontCollection)

  __new__(cls: type,genericFamily: GenericFontFamilies)
  """
  pass
 def __ne__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Name=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the name of this System.Drawing.FontFamily.



Get: Name(self: FontFamily) -> str



"""


 Families=None
 GenericMonospace=None
 GenericSansSerif=None
 GenericSerif=None




class UCOMIRunningObjectTable:
 """ Use System.Runtime.InteropServices.ComTypes.IRunningObjectTable instead. """
 def EnumRunning(self,ppenumMoniker):
  """
  EnumRunning(self: UCOMIRunningObjectTable) -> UCOMIEnumMoniker

  

   Enumerates the objects currently registered as running.
  """
  pass
 def GetObject(self,pmkObjectName,ppunkObject):
  """
  GetObject(self: UCOMIRunningObjectTable,pmkObjectName: UCOMIMoniker) -> object

  

   Returns the registered object if the supplied object name is registered as running.

  

   pmkObjectName: Reference to the moniker to search for in the ROT.
  """
  pass
 def GetTimeOfLastChange(self,pmkObjectName,pfiletime):
  """
  GetTimeOfLastChange(self: UCOMIRunningObjectTable,pmkObjectName: UCOMIMoniker) -> FILETIME

  

   Searches for this moniker in the ROT and reports the recorded time of change,if present.

  

   pmkObjectName: Reference to the moniker to search for in the ROT.
  """
  pass
 def IsRunning(self,pmkObjectName):
  """
  IsRunning(self: UCOMIRunningObjectTable,pmkObjectName: UCOMIMoniker)

   Determines if the specified moniker is currently registered in the Running Object Table.

  

   pmkObjectName: Reference to the moniker to search for in the Running Object Table.
  """
  pass
 def NoteChangeTime(self,dwRegister,pfiletime):
  """
  NoteChangeTime(self: UCOMIRunningObjectTable,dwRegister: int,pfiletime: FILETIME) -> FILETIME

  

   Makes a note of the time that a particular object has changed so IMoniker::GetTimeOfLastChange 

    can report an appropriate change time.

  

  

   dwRegister: The ROT entry of the changed object.

   pfiletime: Reference to the object's last change time.
  """
  pass
 def Register(self,grfFlags,punkObject,pmkObjectName,pdwRegister):
  """
  Register(self: UCOMIRunningObjectTable,grfFlags: int,punkObject: object,pmkObjectName: UCOMIMoniker) -> int

  

   Registers that the supplied object has entered the running state.

  

   grfFlags: Specifies whether the Running Object Table's (ROT) reference to punkObject is weak or strong,

    and controls access to the object through its entry in the ROT.

  

   punkObject: Reference to the object being registered as running.

   pmkObjectName: Reference to the moniker that identifies punkObject.
  """
  pass
 def Revoke(self,dwRegister):
  """
  Revoke(self: UCOMIRunningObjectTable,dwRegister: int)

   Unregisters the specified object from the ROT.

  

   dwRegister: The ROT entry to revoke.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass



class AddingNewItemEventArgs(EventArgs):
 """ AddingNewItemEventArgs() """
 NewItem=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: NewItem(self: AddingNewItemEventArgs) -> object



Set: NewItem(self: AddingNewItemEventArgs)=value

"""





class DataGridTemplateColumn(DataGridColumn):
 """
 Represents a System.Windows.Controls.DataGrid column that hosts template-specified content in its cells.

 

 DataGridTemplateColumn()
 """
 CellEditingTemplate=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the template to use to display the contents of a cell that is in editing mode.



Get: CellEditingTemplate(self: DataGridTemplateColumn) -> DataTemplate



Set: CellEditingTemplate(self: DataGridTemplateColumn)=value

"""

 CellEditingTemplateSelector=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the object that determines which template to use to display the contents of a cell that is in editing mode.



Get: CellEditingTemplateSelector(self: DataGridTemplateColumn) -> DataTemplateSelector



Set: CellEditingTemplateSelector(self: DataGridTemplateColumn)=value

"""

 CellTemplate=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the template to use to display the contents of a cell that is not in editing mode.



Get: CellTemplate(self: DataGridTemplateColumn) -> DataTemplate



Set: CellTemplate(self: DataGridTemplateColumn)=value

"""

 CellTemplateSelector=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the object that determines which template to use to display the contents of a cell that is not in editing mode.



Get: CellTemplateSelector(self: DataGridTemplateColumn) -> DataTemplateSelector



Set: CellTemplateSelector(self: DataGridTemplateColumn)=value

"""

 DataGridOwner=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Windows.Controls.DataGrid control that contains this column.



"""


 CellEditingTemplateProperty=None
 CellEditingTemplateSelectorProperty=None
 CellTemplateProperty=None
 CellTemplateSelectorProperty=None




class Point(object):
 """
 Represents an ordered pair of integer x- and y-coordinates that defines a point in a two-dimensional plane.

 

 Point(x: int,y: int)

 Point(sz: Size)

 Point(dw: int)
 """
 @staticmethod
 def Add(pt,sz):
  """
  Add(pt: Point,sz: Size) -> Point

  

   Adds the specified System.Drawing.Size to the specified System.Drawing.Point.

  

   pt: The System.Drawing.Point to add.

   sz: The System.Drawing.Size to add

   Returns: The System.Drawing.Point that is the result of the addition operation.
  """
  pass
 @staticmethod
 def Ceiling(value):
  """
  Ceiling(value: PointF) -> Point

  

   Converts the specified System.Drawing.PointF to a System.Drawing.Point by rounding the values of 

    the System.Drawing.PointF to the next higher integer values.

  

  

   value: The System.Drawing.PointF to convert.

   Returns: The System.Drawing.Point this method converts to.
  """
  pass
 def Equals(self,obj):
  """
  Equals(self: Point,obj: object) -> bool

  

   Specifies whether this System.Drawing.Point contains the same coordinates as the specified 

    System.Object.

  

  

   obj: The System.Object to test.

   Returns: true if obj is a System.Drawing.Point and has the same coordinates as this System.Drawing.Point.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: Point) -> int

  

   Returns a hash code for this System.Drawing.Point.

   Returns: An integer value that specifies a hash value for this System.Drawing.Point.
  """
  pass
 def Offset(self,*__args):
  """
  Offset(self: Point,p: Point)

   Translates this System.Drawing.Point by the specified System.Drawing.Point.

  

   p: The System.Drawing.Point used offset this System.Drawing.Point.

  Offset(self: Point,dx: int,dy: int)

   Translates this System.Drawing.Point by the specified amount.

  

   dx: The amount to offset the x-coordinate.

   dy: The amount to offset the y-coordinate.
  """
  pass
 @staticmethod
 def Round(value):
  """
  Round(value: PointF) -> Point

  

   Converts the specified System.Drawing.PointF to a System.Drawing.Point object by rounding the 

    System.Drawing.Point values to the nearest integer.

  

  

   value: The System.Drawing.PointF to convert.

   Returns: The System.Drawing.Point this method converts to.
  """
  pass
 @staticmethod
 def Subtract(pt,sz):
  """
  Subtract(pt: Point,sz: Size) -> Point

  

   Returns the result of subtracting specified System.Drawing.Size from the specified 

    System.Drawing.Point.

  

  

   pt: The System.Drawing.Point to be subtracted from.

   sz: The System.Drawing.Size to subtract from the System.Drawing.Point.

   Returns: The System.Drawing.Point that is the result of the subtraction operation.
  """
  pass
 def ToString(self):
  """
  ToString(self: Point) -> str

  

   Converts this System.Drawing.Point to a human-readable string.

   Returns: A string that represents this System.Drawing.Point.
  """
  pass
 @staticmethod
 def Truncate(value):
  """
  Truncate(value: PointF) -> Point

  

   Converts the specified System.Drawing.PointF to a System.Drawing.Point by truncating the values 

    of the System.Drawing.Point.

  

  

   value: The System.Drawing.PointF to convert.

   Returns: The System.Drawing.Point this method converts to.
  """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+y """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__[Point]() -> Point

  

  __new__(cls: type,x: int,y: int)

  __new__(cls: type,sz: Size)

  __new__(cls: type,dw: int)
  """
  pass
 def __ne__(self,*args):
  pass
 def __sub__(self,*args):
  """ x.__sub__(y) <==> x-y """
  pass
 IsEmpty=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether this System.Drawing.Point is empty.



Get: IsEmpty(self: Point) -> bool



"""

 X=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the x-coordinate of this System.Drawing.Point.



Get: X(self: Point) -> int



Set: X(self: Point)=value

"""

 Y=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the y-coordinate of this System.Drawing.Point.



Get: Y(self: Point) -> int



Set: Y(self: Point)=value

"""


 Empty=None




class ProgIdAttribute(Attribute,_Attribute):
 """
 Allows the user to specify the ProgID of a class.

 

 ProgIdAttribute(progId: str)
 """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,progId):
  """ __new__(cls: type,progId: str) """
  pass
 Value=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the ProgID of the class.



Get: Value(self: ProgIdAttribute) -> str



"""





class ToolStripDropDownItemAccessibleObject(ToolStripItemAccessibleObject,IMarshal,IReflect,IAccessible,IEnumVariant,IOleWindow):
 """
 Provides information that accessibility applications use to adjust the user interface of a System.Windows.Forms.ToolStripDropDown for users with impairments.

 

 ToolStripDropDownItemAccessibleObject(item: ToolStripDropDownItem)
 """
 def DoDefaultAction(self):
  """
  DoDefaultAction(self: ToolStripDropDownItemAccessibleObject)

   Performs the default action associated with this accessible object.
  """
  pass
 def GetChild(self,index):
  """
  GetChild(self: ToolStripDropDownItemAccessibleObject,index: int) -> AccessibleObject

  

   Retrieves the accessible child control corresponding to the specified index.

  

   index: The zero-based index of the accessible child control.

   Returns: An System.Windows.Forms.AccessibleObject that represents the accessible child control 

    corresponding to the specified index.
  """
  pass
 def GetChildCount(self):
  """
  GetChildCount(self: ToolStripDropDownItemAccessibleObject) -> int

  

   Retrieves the number of children belonging to an accessible object.

   Returns: The number of children belonging to an accessible object.
  """
  pass
 def MemberwiseClone(self,*args):
  """
  MemberwiseClone(self: MarshalByRefObject,cloneIdentity: bool) -> MarshalByRefObject

  

   Creates a shallow copy of the current System.MarshalByRefObject object.

  

   cloneIdentity: false to delete the current System.MarshalByRefObject object's identity,which will cause the 

    object to be assigned a new identity when it is marshaled across a remoting boundary. A value of 

    false is usually appropriate. true to copy the current System.MarshalByRefObject object's 

    identity to its clone,which will cause remoting client calls to be routed to the remote server 

    object.

  

   Returns: A shallow copy of the current System.MarshalByRefObject object.

  MemberwiseClone(self: object) -> object

  

   Creates a shallow copy of the current System.Object.

   Returns: A shallow copy of the current System.Object.
  """
  pass
 def UseStdAccessibleObjects(self,*args):
  """
  UseStdAccessibleObjects(self: AccessibleObject,handle: IntPtr,objid: int)

   Associates an object with an instance of an System.Windows.Forms.AccessibleObject based on the 

    handle and the object id of the object.

  

  

   handle: An System.IntPtr that contains the handle of the object.

   objid: An Int that defines the type of object that the handle parameter refers to.

  UseStdAccessibleObjects(self: AccessibleObject,handle: IntPtr)

   Associates an object with an instance of an System.Windows.Forms.AccessibleObject based on the 

    handle of the object.

  

  

   handle: An System.IntPtr that contains the handle of the object.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,item):
  """ __new__(cls: type,item: ToolStripDropDownItem) """
  pass
 def __str__(self,*args):
  pass
 Role=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the role of this accessible object.



Get: Role(self: ToolStripDropDownItemAccessibleObject) -> AccessibleRole



"""





class IObservable:
 # no doc
 def Subscribe(self,observer):
  """
  Subscribe(self: IObservable[T],observer: IObserver[T]) -> IDisposable

  

   Notifies the provider that an observer is to receive notifications.

  

   observer: The object that is to receive notifications.

   Returns: A reference to an interface that allows observers to stop receiving notifications before the 

    provider has finished sending them.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass



# encoding: utf-8
# module System.Security.Authentication.ExtendedProtection calls itself ExtendedProtection
# from System,Version=4.0.0.0,Culture=neutral,PublicKeyToken=b77a5c561934e089
# by generator 1.145
""" NamespaceTracker represent a CLS namespace. """
# no imports

# no functions
# classes

class ChannelBinding(SafeHandleZeroOrMinusOneIsInvalid,IDisposable):
 """ The System.Security.Authentication.ExtendedProtection.ChannelBinding class encapsulates a pointer to the opaque data used to bind an authenticated transaction to a secure channel. """
 def Dispose(self):
  """
  Dispose(self: SafeHandle,disposing: bool)

   Releases the unmanaged resources used by the System.Runtime.InteropServices.SafeHandle class 

    specifying whether to perform a normal dispose operation.

  

  

   disposing: true for a normal dispose operation; false to finalize the handle.
  """
  pass
 def ReleaseHandle(self,*args):
  """
  ReleaseHandle(self: SafeHandle) -> bool

  

   When overridden in a derived class,executes the code required to free the handle.

   Returns: true if the handle is released successfully; otherwise,in the event of a catastrophic failure,

    false. In this case,it generates a releaseHandleFailed MDA Managed Debugging Assistant.
  """
  pass
 def SetHandle(self,*args):
  """
  SetHandle(self: SafeHandle,handle: IntPtr)

   Sets the handle to the specified pre-existing handle.

  

   handle: The pre-existing handle to use.
  """
  pass
 def __enter__(self,*args):
  """
  __enter__(self: IDisposable) -> object

  

   Provides the implementation of __enter__ for objects which implement IDisposable.
  """
  pass
 def __exit__(self,*args):
  """
  __exit__(self: IDisposable,exc_type: object,exc_value: object,exc_back: object)

   Provides the implementation of __exit__ for objects which implement IDisposable.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,*args): #cannot find CLR constructor
  """
  __new__(cls: type)

  __new__(cls: type,ownsHandle: bool)
  """
  pass
 Size=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """The System.Security.Authentication.ExtendedProtection.ChannelBinding.Size property gets the size,in bytes,of the channel binding token associated with the System.Security.Authentication.ExtendedProtection.ChannelBinding instance.



Get: Size(self: ChannelBinding) -> int



"""


 handle=None


class ChannelBindingKind(Enum,IComparable,IFormattable,IConvertible):
 """
 The System.Security.Authentication.ExtendedProtection.ChannelBindingKind enumeration represents the kinds of channel bindings that can be queried from secure channels.

 

 enum ChannelBindingKind,values: Endpoint (26),Unique (25),Unknown (0)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Endpoint=None
 Unique=None
 Unknown=None
 value__=None


class ExtendedProtectionPolicy(object,ISerializable):
 """
 The System.Security.Authentication.ExtendedProtection.ExtendedProtectionPolicy class represents the extended protection policy used by the server to validate incoming client connections.

 

 ExtendedProtectionPolicy(policyEnforcement: PolicyEnforcement,protectionScenario: ProtectionScenario,customServiceNames: ServiceNameCollection)

 ExtendedProtectionPolicy(policyEnforcement: PolicyEnforcement,protectionScenario: ProtectionScenario,customServiceNames: ICollection)

 ExtendedProtectionPolicy(policyEnforcement: PolicyEnforcement,customChannelBinding: ChannelBinding)

 ExtendedProtectionPolicy(policyEnforcement: PolicyEnforcement)
 """
 def ToString(self):
  """
  ToString(self: ExtendedProtectionPolicy) -> str

  

   Gets a string representation for the extended protection policy instance.

   Returns: A System.String instance that contains the representation of the 

    System.Security.Authentication.ExtendedProtection.ExtendedProtectionPolicy instance.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,policyEnforcement,*__args):
  """
  __new__(cls: type,policyEnforcement: PolicyEnforcement,protectionScenario: ProtectionScenario,customServiceNames: ServiceNameCollection)

  __new__(cls: type,policyEnforcement: PolicyEnforcement,protectionScenario: ProtectionScenario,customServiceNames: ICollection)

  __new__(cls: type,policyEnforcement: PolicyEnforcement,customChannelBinding: ChannelBinding)

  __new__(cls: type,policyEnforcement: PolicyEnforcement)

  __new__(cls: type,info: SerializationInfo,context: StreamingContext)
  """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 def __str__(self,*args):
  pass
 CustomChannelBinding=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a custom channel binding token (CBT) to use for validation.



Get: CustomChannelBinding(self: ExtendedProtectionPolicy) -> ChannelBinding



"""

 CustomServiceNames=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the custom Service Provider Name (SPN) list used to match against a client's SPN.



Get: CustomServiceNames(self: ExtendedProtectionPolicy) -> ServiceNameCollection



"""

 PolicyEnforcement=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets when the extended protection policy should be enforced.



Get: PolicyEnforcement(self: ExtendedProtectionPolicy) -> PolicyEnforcement



"""

 ProtectionScenario=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the kind of protection enforced by the extended protection policy.



Get: ProtectionScenario(self: ExtendedProtectionPolicy) -> ProtectionScenario



"""


 OSSupportsExtendedProtection=True


class ExtendedProtectionPolicyTypeConverter(TypeConverter):
 """
 The System.Security.Authentication.ExtendedProtection.ExtendedProtectionPolicyTypeConverter class represents the type converter for extended protection policy used by the server to validate incoming client connections.

 

 ExtendedProtectionPolicyTypeConverter()
 """
 def CanConvertTo(self,*__args):
  """
  CanConvertTo(self: ExtendedProtectionPolicyTypeConverter,context: ITypeDescriptorContext,destinationType: Type) -> bool

  

   Returns whether this converter can convert the object to the specified type.

  

   context: The object to convert.

   destinationType: A System.Type that represents the type you want to convert to.

   Returns: true if this converter can perform the conversion; otherwise false.
  """
  pass
 def ConvertTo(self,*__args):
  """
  ConvertTo(self: ExtendedProtectionPolicyTypeConverter,context: ITypeDescriptorContext,culture: CultureInfo,value: object,destinationType: Type) -> object

  

   Convert the object to the specified type

  

   context: An System.ComponentModel.ITypeDescriptorContext that provides a format context.

   culture: A System.Globalization.CultureInfo object. If null is passed,the current culture is assumed.

   value: The System.Object to convert. This should be a 

    System.Security.Authentication.ExtendedProtection.ExtendedProtectionPolicy object.

  

   destinationType: The System.Type to convert the value parameter to.

   Returns: An System.Object that represents the converted value parameter.
  """
  pass

class PolicyEnforcement(Enum,IComparable,IFormattable,IConvertible):
 """
 The System.Security.Authentication.ExtendedProtection.PolicyEnforcement enumeration specifies when the System.Security.Authentication.ExtendedProtection.ExtendedProtectionPolicy should be enforced.

 

 enum PolicyEnforcement,values: Always (2),Never (0),WhenSupported (1)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Always=None
 Never=None
 value__=None
 WhenSupported=None


class ProtectionScenario(Enum,IComparable,IFormattable,IConvertible):
 """
 The System.Security.Authentication.ExtendedProtection.ProtectionScenario enumeration specifies the protection scenario enforced by the policy.

 

 enum ProtectionScenario,values: TransportSelected (0),TrustedProxy (1)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 TransportSelected=None
 TrustedProxy=None
 value__=None


class ServiceNameCollection(ReadOnlyCollectionBase,ICollection,IEnumerable):
 """
 The System.Security.Authentication.ExtendedProtection.ServiceNameCollection class is a read-only collection of service principal names.

 

 ServiceNameCollection(items: ICollection)
 """
 def Contains(self,searchServiceName):
  """ Contains(self: ServiceNameCollection,searchServiceName: str) -> bool """
  pass
 def Merge(self,*__args):
  """
  Merge(self: ServiceNameCollection,serviceNames: IEnumerable) -> ServiceNameCollection

  

   Merges the current System.Security.Authentication.ExtendedProtection.ServiceNameCollection with 

    the specified values to create a new 

    System.Security.Authentication.ExtendedProtection.ServiceNameCollection containing the union.

  

  

   serviceNames: An instance of the System.Collections.IEnumerable class that contains the specified values of 

    service names to be merged.

  

   Returns: A new System.Security.Authentication.ExtendedProtection.ServiceNameCollection instance that 

    contains the union of the existing 

    System.Security.Authentication.ExtendedProtection.ServiceNameCollection instance merged with the 

    specified values.

  

  Merge(self: ServiceNameCollection,serviceName: str) -> ServiceNameCollection

  

   Merges the current System.Security.Authentication.ExtendedProtection.ServiceNameCollection with 

    the specified values to create a new 

    System.Security.Authentication.ExtendedProtection.ServiceNameCollection containing the union.

  

  

   serviceName: A string that contains the specified values of service names to be used to initialize the class.

   Returns: A new System.Security.Authentication.ExtendedProtection.ServiceNameCollection instance that 

    contains the union of the existing 

    System.Security.Authentication.ExtendedProtection.ServiceNameCollection instance merged with the 

    specified values.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 @staticmethod
 def __new__(self,items):
  """ __new__(cls: type,items: ICollection) """
  pass
 def __reduce_ex__(self,*args):
  pass
 InnerList=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the list of elements contained in the System.Collections.ReadOnlyCollectionBase instance.



"""



class TokenBinding(object):
 # no doc
 def GetRawTokenBindingId(self):
  """ GetRawTokenBindingId(self: TokenBinding) -> Array[Byte] """
  pass
 BindingType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: BindingType(self: TokenBinding) -> TokenBindingType



"""



class TokenBindingType(Enum,IComparable,IFormattable,IConvertible):
 """ enum TokenBindingType,values: Provided (0),Referred (1) """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Provided=None
 Referred=None
 value__=None


# variables with complex values




class LicFileLicenseProvider(LicenseProvider):
 """
 Provides an implementation of a System.ComponentModel.LicenseProvider. The provider works in a similar fashion to the Microsoft .NET Framework standard licensing model.

 

 LicFileLicenseProvider()
 """
 def GetKey(self,*args):
  """
  GetKey(self: LicFileLicenseProvider,type: Type) -> str

  

   Returns a key for the specified type.

  

   type: The object type to return the key.

   Returns: A confirmation that the type parameter is licensed.
  """
  pass
 def GetLicense(self,context,type,instance,allowExceptions):
  """
  GetLicense(self: LicFileLicenseProvider,context: LicenseContext,type: Type,instance: object,allowExceptions: bool) -> License

  

   Returns a license for the instance of the component,if one is available.

  

   context: A System.ComponentModel.LicenseContext that specifies where you can use the licensed object.

   type: A System.Type that represents the component requesting the System.ComponentModel.License.

   instance: An object that requests the System.ComponentModel.License.

   allowExceptions: true if a System.ComponentModel.LicenseException should be thrown when a component cannot be 

    granted a license; otherwise,false.

  

   Returns: A valid System.ComponentModel.License. If this method cannot find a valid 

    System.ComponentModel.License or a valid context parameter,it returns null.
  """
  pass
 def IsKeyValid(self,*args):
  """
  IsKeyValid(self: LicFileLicenseProvider,key: str,type: Type) -> bool

  

   Determines whether the key that the 

    System.ComponentModel.LicFileLicenseProvider.GetLicense(System.ComponentModel.LicenseContext,Syst

    em.Type,System.Object,System.Boolean) method retrieves is valid for the specified type.

  

  

   key: The System.ComponentModel.License.LicenseKey to check.

   type: A System.Type that represents the component requesting the System.ComponentModel.License.

   Returns: true if the key is a valid System.ComponentModel.License.LicenseKey for the specified type; 

    otherwise,false.
  """
  pass



class TreeNodeCollection(object,IList,ICollection,IEnumerable):
 """ Represents a collection of System.Windows.Forms.TreeNode objects. """
 def Add(self,*__args):
  """
  Add(self: TreeNodeCollection,key: str,text: str,imageIndex: int,selectedImageIndex: int) -> TreeNode

  

   Creates a tree node with the specified key,text,and images,and adds it to the collection.

  

   key: The name of the tree node.

   text: The text to display in the tree node.

   imageIndex: The index of the image to display in the tree node.

   selectedImageIndex: The index of the image to be displayed in the tree node when it is in a selected state.

   Returns: The tree node that was added to the collection.

  Add(self: TreeNodeCollection,key: str,text: str,imageKey: str,selectedImageKey: str) -> TreeNode

  

   Creates a tree node with the specified key,text,and images,and adds it to the collection.

  

   key: The name of the tree node.

   text: The text to display in the tree node.

   imageKey: The key of the image to display in the tree node.

   selectedImageKey: The key of the image to display when the node is in a selected state.

   Returns: The System.Windows.Forms.TreeNode that was added to the collection.

  Add(self: TreeNodeCollection,node: TreeNode) -> int

  

   Adds a previously created tree node to the end of the tree node collection.

  

   node: The System.Windows.Forms.TreeNode to add to the collection.

   Returns: The zero-based index value of the System.Windows.Forms.TreeNode added to the tree node 

    collection.

  

  Add(self: TreeNodeCollection,key: str,text: str,imageKey: str) -> TreeNode

  

   Creates a tree node with the specified key,text,and image,and adds it to the collection.

  

   key: The name of the tree node.

   text: The text to display in the tree node.

   imageKey: The image to display in the tree node.

   Returns: The System.Windows.Forms.TreeNode that was added to the collection.

  Add(self: TreeNodeCollection,text: str) -> TreeNode

  

   Adds a new tree node with the specified label text to the end of the current tree node 

    collection.

  

  

   text: The label text displayed by the System.Windows.Forms.TreeNode.

   Returns: A System.Windows.Forms.TreeNode that represents the tree node being added to the collection.

  Add(self: TreeNodeCollection,key: str,text: str) -> TreeNode

  

   Creates a new tree node with the specified key and text,and adds it to the collection.

  

   key: The name of the tree node.

   text: The text to display in the tree node.

   Returns: The System.Windows.Forms.TreeNode that was added to the collection.

  Add(self: TreeNodeCollection,key: str,text: str,imageIndex: int) -> TreeNode

  

   Creates a tree node with the specified key,text,and image,and adds it to the collection.

  

   key: The name of the tree node.

   text: The text to display in the tree node.

   imageIndex: The index of the image to display in the tree node.

   Returns: The System.Windows.Forms.TreeNode that was added to the collection.
  """
  pass
 def AddRange(self,nodes):
  """
  AddRange(self: TreeNodeCollection,nodes: Array[TreeNode])

   Adds an array of previously created tree nodes to the collection.

  

   nodes: An array of System.Windows.Forms.TreeNode objects representing the tree nodes to add to the 

    collection.
  """
  pass
 def Clear(self):
  """
  Clear(self: TreeNodeCollection)

   Removes all tree nodes from the collection.
  """
  pass
 def Contains(self,node):
  """
  Contains(self: TreeNodeCollection,node: TreeNode) -> bool

  

   Determines whether the specified tree node is a member of the collection.

  

   node: The System.Windows.Forms.TreeNode to locate in the collection.

   Returns: true if the System.Windows.Forms.TreeNode is a member of the collection; otherwise,false.
  """
  pass
 def ContainsKey(self,key):
  """
  ContainsKey(self: TreeNodeCollection,key: str) -> bool

  

   Determines whether the collection contains a tree node with the specified key.

  

   key: The name of the System.Windows.Forms.TreeNode to search for.

   Returns: true to indicate the collection contains a System.Windows.Forms.TreeNode with the specified key; 

    otherwise,false.
  """
  pass
 def CopyTo(self,dest,index):
  """
  CopyTo(self: TreeNodeCollection,dest: Array,index: int)

   Copies the entire collection into an existing array at a specified location within the array.

  

   dest: The destination array.

   index: The index in the destination array at which storing begins.
  """
  pass
 def Find(self,key,searchAllChildren):
  """
  Find(self: TreeNodeCollection,key: str,searchAllChildren: bool) -> Array[TreeNode]

  

   Finds the tree nodes with specified key,optionally searching subnodes.

  

   key: The name of the tree node to search for.

   searchAllChildren: true to search child nodes of tree nodes; otherwise,false.

   Returns: An array of System.Windows.Forms.TreeNode objects whose System.Windows.Forms.TreeNode.Name 

    property matches the specified key.
  """
  pass
 def GetEnumerator(self):
  """
  GetEnumerator(self: TreeNodeCollection) -> IEnumerator

  

   Returns an enumerator that can be used to iterate through the tree node collection.

   Returns: An System.Collections.IEnumerator that represents the tree node collection.
  """
  pass
 def IndexOf(self,node):
  """
  IndexOf(self: TreeNodeCollection,node: TreeNode) -> int

  

   Returns the index of the specified tree node in the collection.

  

   node: The System.Windows.Forms.TreeNode to locate in the collection.

   Returns: The zero-based index of the item found in the tree node collection; otherwise,-1.
  """
  pass
 def IndexOfKey(self,key):
  """
  IndexOfKey(self: TreeNodeCollection,key: str) -> int

  

   Returns the index of the first occurrence of a tree node with the specified key.

  

   key: The name of the tree node to search for.

   Returns: The zero-based index of the first occurrence of a tree node with the specified key,if found; 

    otherwise,-1.
  """
  pass
 def Insert(self,index,*__args):
  """
  Insert(self: TreeNodeCollection,index: int,key: str,text: str,imageKey: str) -> TreeNode

  

   Creates a tree node with the specified key,text,and image,and inserts it into the collection 

    at the specified index.

  

  

   index: The location within the collection to insert the node.

   key: The name of the tree node.

   text: The text to display in the tree node.

   imageKey: The key of the image to display in the tree node.

   Returns: The System.Windows.Forms.TreeNode that was inserted in the collection.

  Insert(self: TreeNodeCollection,index: int,key: str,text: str,imageIndex: int,selectedImageIndex: int) -> TreeNode

  

   Creates a tree node with the specified key,text,and images,and inserts it into the collection 

    at the specified index.

  

  

   index: The location within the collection to insert the node.

   key: The name of the tree node.

   text: The text to display in the tree node.

   imageIndex: The index of the image to display in the tree node.

   selectedImageIndex: The index of the image to display in the tree node when it is in a selected state.

   Returns: The System.Windows.Forms.TreeNode that was inserted in the collection.

  Insert(self: TreeNodeCollection,index: int,key: str,text: str,imageKey: str,selectedImageKey: str) -> TreeNode

  

   Creates a tree node with the specified key,text,and images,and inserts it into the collection 

    at the specified index.

  

  

   index: The location within the collection to insert the node.

   key: The name of the tree node.

   text: The text to display in the tree node.

   imageKey: The key of the image to display in the tree node.

   selectedImageKey: The key of the image to display in the tree node when it is in a selected state.

   Returns: The System.Windows.Forms.TreeNode that was inserted in the collection.

  Insert(self: TreeNodeCollection,index: int,key: str,text: str,imageIndex: int) -> TreeNode

  

   Creates a tree node with the specified key,text,and image,and inserts it into the collection 

    at the specified index.

  

  

   index: The location within the collection to insert the node.

   key: The name of the tree node.

   text: The text to display in the tree node.

   imageIndex: The index of the image to display in the tree node.

   Returns: The System.Windows.Forms.TreeNode that was inserted in the collection.

  Insert(self: TreeNodeCollection,index: int,node: TreeNode)

   Inserts an existing tree node into the tree node collection at the specified location.

  

   index: The indexed location within the collection to insert the tree node.

   node: The System.Windows.Forms.TreeNode to insert into the collection.

  Insert(self: TreeNodeCollection,index: int,text: str) -> TreeNode

  

   Creates a tree node with the specified text and inserts it at the specified index.

  

   index: The location within the collection to insert the node.

   text: The text to display in the tree node.

   Returns: The System.Windows.Forms.TreeNode that was inserted in the collection.

  Insert(self: TreeNodeCollection,index: int,key: str,text: str) -> TreeNode

  

   Creates a tree node with the specified text and key,and inserts it into the collection.

  

   index: The location within the collection to insert the node.

   key: The name of the tree node.

   text: The text to display in the tree node.

   Returns: The System.Windows.Forms.TreeNode that was inserted in the collection.
  """
  pass
 def Remove(self,node):
  """
  Remove(self: TreeNodeCollection,node: TreeNode)

   Removes the specified tree node from the tree node collection.

  

   node: The System.Windows.Forms.TreeNode to remove.
  """
  pass
 def RemoveAt(self,index):
  """
  RemoveAt(self: TreeNodeCollection,index: int)

   Removes a tree node from the tree node collection at a specified index.

  

   index: The index of the System.Windows.Forms.TreeNode to remove.
  """
  pass
 def RemoveByKey(self,key):
  """
  RemoveByKey(self: TreeNodeCollection,key: str)

   Removes the tree node with the specified key from the collection.

  

   key: The name of the tree node to remove from the collection.
  """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+yx.__add__(y) <==> x+yx.__add__(y) <==> x+yx.__add__(y) <==> x+yx.__add__(y) <==> x+yx.__add__(y) <==> x+yx.__add__(y) <==> x+y """
  pass
 def __contains__(self,*args):
  """
  __contains__(self: IList,value: object) -> bool

  

   Determines whether the System.Collections.IList contains a specific value.

  

   value: The object to locate in the System.Collections.IList.

   Returns: true if the System.Object is found in the System.Collections.IList; otherwise,false.
  """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y]x.__getitem__(y) <==> x[y] """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 def __len__(self,*args):
  """ x.__len__() <==> len(x) """
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 def __setitem__(self,*args):
  """ x.__setitem__(i,y) <==> x[i]= """
  pass
 Count=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the total number of System.Windows.Forms.TreeNode objects in the collection.



Get: Count(self: TreeNodeCollection) -> int



"""

 IsReadOnly=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the collection is read-only.



Get: IsReadOnly(self: TreeNodeCollection) -> bool



"""





class IDispatchImplAttribute(Attribute,_Attribute):
 """
 Indicates which IDispatch implementation the common language runtime uses when exposing dual interfaces and dispinterfaces to COM.

 

 IDispatchImplAttribute(implType: IDispatchImplType)

 IDispatchImplAttribute(implType: Int16)
 """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,implType):
  """
  __new__(cls: type,implType: IDispatchImplType)

  __new__(cls: type,implType: Int16)
  """
  pass
 Value=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Runtime.InteropServices.IDispatchImplType value used by the class.



Get: Value(self: IDispatchImplAttribute) -> IDispatchImplType



"""





class ToolboxItemAttribute(Attribute,_Attribute):
 """
 Represents an attribute of a toolbox item.

 

 ToolboxItemAttribute(defaultType: bool)

 ToolboxItemAttribute(toolboxItemTypeName: str)

 ToolboxItemAttribute(toolboxItemType: Type)
 """
 def Equals(self,obj):
  """
  Equals(self: ToolboxItemAttribute,obj: object) -> bool

  

   obj: The object to compare.
  """
  pass
 def GetHashCode(self):
  """ GetHashCode(self: ToolboxItemAttribute) -> int """
  pass
 def IsDefaultAttribute(self):
  """
  IsDefaultAttribute(self: ToolboxItemAttribute) -> bool

  

   Gets a value indicating whether the current value of the attribute is the default value for the 

    attribute.

  

   Returns: true if the current value of the attribute is the default; otherwise,false.
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type,defaultType: bool)

  __new__(cls: type,toolboxItemTypeName: str)

  __new__(cls: type,toolboxItemType: Type)
  """
  pass
 def __ne__(self,*args):
  pass
 ToolboxItemType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the type of the toolbox item.



Get: ToolboxItemType(self: ToolboxItemAttribute) -> Type



"""

 ToolboxItemTypeName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the name of the type of the current System.Drawing.Design.ToolboxItem.



Get: ToolboxItemTypeName(self: ToolboxItemAttribute) -> str



"""


 Default=None
 None=None

